/*******************************************************
 * 
 * Bossa events
 *
 *******************************************************/

/*
 * Bossa events are structured in six top level classes:
 *
 *  event       mask              description
 * =======   ============      =====================
 * BLOCK     0x01........      blocking events
 * UNBLOCK   0x02........      unblocking events
 * YIELD     0x03........      process-related events
 * SYSTEM    0x04........      system events
 * PROCESS   0x05........      process-related events
 * BOSSA     0x06........      Bossa run-time events
 *
 */

#ifndef BOSSA_EVENTS
#define BOSSA_EVENTS

#define MAIN_REST_INIT                           	 0x00000101
#define MAIN_START_KERNEL                        	 0x00000102
#define KERNEL_SCHED_WAKE_UP_PROCESS             	 0x00000201
#define KERNEL_SCHED_SCHEDULE_TIMEOUT            	 0x00000202
#define KERNEL_SCHED___WAKE_UP_COMMON            	 0x00000203
#define KERNEL_SCHED_WAIT_FOR_COMPLETION         	 0x00000204
#define KERNEL_SCHED_INTERRUPTIBLE_SLEEP_ON      	 0x00000205
#define KERNEL_SCHED_INTERRUPTIBLE_SLEEP_ON_TIMEOUT 	 0x00000206
#define KERNEL_SCHED_SLEEP_ON                    	 0x00000207
#define KERNEL_SCHED_SLEEP_ON_TIMEOUT            	 0x00000208
#define KERNEL_SCHED_SYS_NICE                    	 0x00000209
#define KERNEL_SCHED_YIELD                       	 0x0000020a
#define KERNEL_SCHED___COND_RESCHED              	 0x0000020b
#define KERNEL_FORK_DO_FORK                      	 0x00000301
#define KERNEL_PRINTK_DO_SYSLOG                  	 0x00000401
#define KERNEL_PRINTK_CONSOLE_CONDITIONAL_SCHEDULE 	 0x00000402
#define KERNEL_EXIT_RELEASE_TASK                 	 0x00000501
#define KERNEL_EXIT_DO_EXIT                      	 0x00000502
#define KERNEL_EXIT_SYS_WAIT4                    	 0x00000503
#define KERNEL_SOFTIRQ_KSOFTIRQD                 	 0x00000601
#define KERNEL_TIMER_UPDATE_PROCESS_TIMES        	 0x00000701
#define KERNEL_TIMER_UPDATE_TIMES                	 0x00000702
#define KERNEL_TIMER_SYS_NANOSLEEP               	 0x00000703
#define KERNEL_SIGNAL_SYS_RT_SIGTIMEDWAIT        	 0x00000801
#define KERNEL_CONTEXT_CONTEXT_THREAD            	 0x00000901
#define KERNEL_CONTEXT_FLUSH_SCHEDULED_TASKS     	 0x00000902
#define DRIVERS_ACPI_OSL_ACPI_OS_SLEEP           	 0x00000a01
#define DRIVERS_ACPI_OSL_ACPI_OS_WAIT_SEMAPHORE  	 0x00000a02
#define DRIVERS_ACPI_BUS_ACPI_BUS_RECEIVE_EVENT  	 0x00000a03
#define DRIVERS_ATM_ENI_NETIF_POLL_DISABLE       	 0x00000b01
#define DRIVERS_ATM_ENI_CLOSE_RX                 	 0x00000b02
#define DRIVERS_ATM_ENI_CLOSE_TX                 	 0x00000b03
#define DRIVERS_ATM_SUNI_NETIF_POLL_DISABLE      	 0x00000b04
#define DRIVERS_ATM_ZATM_NETIF_POLL_DISABLE      	 0x00000b05
#define DRIVERS_ATM_UPD98402_NETIF_POLL_DISABLE  	 0x00000b06
#define DRIVERS_ATM_NICSTAR_NETIF_POLL_DISABLE   	 0x00000b07
#define DRIVERS_ATM_NICSTAR_NS_CLOSE             	 0x00000b08
#define DRIVERS_ATM_IDT77252_NETIF_POLL_DISABLE  	 0x00000b09
#define DRIVERS_ATM_IDT77252_IDT77252_CLOSE      	 0x00000b0a
#define DRIVERS_ATM_IDT77105_NETIF_POLL_DISABLE  	 0x00000b0b
#define DRIVERS_ATM_ATMTCP_NETIF_POLL_DISABLE    	 0x00000b0c
#define DRIVERS_ATM_ATMTCP_ATMTCP_SEND_CONTROL   	 0x00000b0d
#define DRIVERS_ATM_IPHASE_NETIF_POLL_DISABLE    	 0x00000b0e
#define DRIVERS_ATM_FIRESTREAM_NETIF_POLL_DISABLE 	 0x00000b0f
#define DRIVERS_ATM_FIRESTREAM_SUBMIT_QENTRY     	 0x00000b10
#define DRIVERS_ATM_FIRESTREAM_FS_INIT           	 0x00000b11
#define DRIVERS_ATM_LANAI_NETIF_POLL_DISABLE     	 0x00000b12
#define DRIVERS_ATM_LANAI_LANAI_SHUTDOWN_TX_VCI  	 0x00000b13
#define DRIVERS_ATM_FORE200E_NETIF_POLL_DISABLE  	 0x00000b14
#define DRIVERS_ATM_HE_NETIF_POLL_DISABLE        	 0x00000b15
#define DRIVERS_ATM_HE_HE_CLOSE                  	 0x00000b16
#define DRIVERS_BLOCK_PARIDE_PARIDE_PI_CLAIM     	 0x00000c01
#define DRIVERS_BLOCK_PARIDE_PD_PD_OPEN          	 0x00000c02
#define DRIVERS_BLOCK_PARIDE_PCD_PCD_SLEEP       	 0x00000c03
#define DRIVERS_BLOCK_PARIDE_PF_PF_SLEEP         	 0x00000c04
#define DRIVERS_BLOCK_PARIDE_PT_PT_SLEEP         	 0x00000c05
#define DRIVERS_BLOCK_PARIDE_PG_PG_SLEEP         	 0x00000c06
#define DRIVERS_BLOCK_LL_RW_BLK___GET_REQUEST_WAIT 	 0x00000d01
#define DRIVERS_BLOCK_FLOPPY__LOCK_FDC           	 0x00000e01
#define DRIVERS_BLOCK_FLOPPY_WAIT_TIL_DONE       	 0x00000e02
#define DRIVERS_BLOCK_LOOP_LOOP_GET_BUFFER       	 0x00000f01
#define DRIVERS_BLOCK_XD_XD_WAITPORT             	 0x00001001
#define DRIVERS_BLOCK_XD_XD_INITDRIVES           	 0x00001002
#define DRIVERS_BLOCK_XD_XD_WD_INIT_CONTROLLER   	 0x00001003
#define DRIVERS_BLOCK_XD_XD_XEBEC_INIT_CONTROLLER 	 0x00001004
#define DRIVERS_BLOCK_CCISS_POLLCOMPLETE         	 0x00001101
#define DRIVERS_BLOCK_CCISS_CCISS_PCI_INIT       	 0x00001102
#define DRIVERS_BLOCK_CCISS_CCISS_MONITOR        	 0x00001103
#define DRIVERS_BLOCK_DAC960_DAC960_WAITFORCOMMAND 	 0x00001201
#define DRIVERS_BLOCK_DAC960_DAC960_USERIOCTL    	 0x00001202
#define DRIVERS_BLOCK_NBD_NETIF_POLL_DISABLE     	 0x00001301
#define DRIVERS_BLUETOOTH_HCI_USB_WAIT_MS        	 0x00001401
#define DRIVERS_BLUETOOTH_HCI_USB_NETIF_POLL_DISABLE 	 0x00001402
#define DRIVERS_BLUETOOTH_HCI_VHCI_NETIF_POLL_DISABLE 	 0x00001403
#define DRIVERS_BLUETOOTH_HCI_VHCI_HCI_VHCI_CHR_READ 	 0x00001404
#define DRIVERS_BLUETOOTH_HCI_LDISC_NETIF_POLL_DISABLE 	 0x00001405
#define DRIVERS_BLUETOOTH_HCI_H4_NETIF_POLL_DISABLE 	 0x00001406
#define DRIVERS_BLUETOOTH_HCI_BCSP_NETIF_POLL_DISABLE 	 0x00001407
#define DRIVERS_BLUETOOTH_BFUSB_WAIT_MS          	 0x00001408
#define DRIVERS_BLUETOOTH_BFUSB_NETIF_POLL_DISABLE 	 0x00001409
#define DRIVERS_BLUETOOTH_DTL1_CS_NETIF_POLL_DISABLE 	 0x0000140a
#define DRIVERS_BLUETOOTH_DTL1_CS_DTL1_OPEN      	 0x0000140b
#define DRIVERS_BLUETOOTH_BT3C_CS_NETIF_POLL_DISABLE 	 0x0000140c
#define DRIVERS_BLUETOOTH_BT3C_CS_BT3C_OPEN      	 0x0000140d
#define DRIVERS_BLUETOOTH_BLUECARD_CS_NETIF_POLL_DISABLE 	 0x0000140e
#define DRIVERS_BLUETOOTH_BLUECARD_CS_BLUECARD_OPEN 	 0x0000140f
#define DRIVERS_BLUETOOTH_BTUART_CS_NETIF_POLL_DISABLE 	 0x00001410
#define DRIVERS_BLUETOOTH_BTUART_CS_BTUART_OPEN  	 0x00001411
#define DRIVERS_CDROM_CDU31A_SONY_SLEEP          	 0x00001501
#define DRIVERS_CDROM_CDU31A_RESTART_ON_ERROR    	 0x00001502
#define DRIVERS_CDROM_CDU31A_DO_SONY_CD_CMD      	 0x00001503
#define DRIVERS_CDROM_MCD_MCD_OPEN               	 0x00001504
#define DRIVERS_CDROM_SBPCD_SBP_SLEEP            	 0x00001505
#define DRIVERS_CDROM_SBPCD2_SBP_SLEEP           	 0x00001506
#define DRIVERS_CDROM_SBPCD3_SBP_SLEEP           	 0x00001507
#define DRIVERS_CDROM_SBPCD4_SBP_SLEEP           	 0x00001508
#define DRIVERS_CDROM_SONYCD535_SONY_SLEEP       	 0x00001509
#define DRIVERS_CDROM_SONYCD535_DO_CDU535_REQUEST 	 0x0000150a
#define DRIVERS_CDROM_SONYCD535_SONY535_INIT     	 0x0000150b
#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_DMA_PRIORITY 	 0x00001601
#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_DMA_SEND_BUFFERS 	 0x00001602
#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_LOCK 	 0x00001603
#define DRIVERS_CHAR_DRM_4_0_CONTEXT_DRM_RMCTX   	 0x00001604
#define DRIVERS_CHAR_DRM_4_0_LISTS_DRM_FREELIST_GET 	 0x00001605
#define DRIVERS_CHAR_DRM_4_0_LOCK_DRM_FLUSH_QUEUE 	 0x00001606
#define DRIVERS_CHAR_DRM_4_0_DMA_DRM_DMA_ENQUEUE 	 0x00001607
#define DRIVERS_CHAR_DRM_4_0_R128_DRV_R128_LOCK  	 0x00001608
#define DRIVERS_CHAR_DRM_4_0_RADEON_DRV_RADEON_LOCK 	 0x00001609
#define DRIVERS_CHAR_DRM_4_0_MGA_DRV_MGA_RELEASE 	 0x0000160a
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_FREELIST_GET 	 0x0000160b
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_ADVANCE_PRIMARY 	 0x0000160c
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_FLUSH_QUEUE 	 0x0000160d
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_LOCK    	 0x0000160e
#define DRIVERS_CHAR_DRM_4_0_I810_DRV_I810_RELEASE 	 0x0000160f
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_DMA_QUIESCENT 	 0x00001610
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_FLUSH_QUEUE 	 0x00001611
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_LOCK  	 0x00001612
#define DRIVERS_CHAR_FTAPE_LOWLEVEL_FDC_IO_FDC_INTERRUPT_WAIT 	 0x00001701
#define DRIVERS_CHAR_FTAPE_LOWLEVEL_FTAPE_IO_FTAPE_SLEEP 	 0x00001702
#define DRIVERS_CHAR_FTAPE_ZFTAPE_ZFTAPE_BUFFERS_ZFT_KMALLOC 	 0x00001703
#define DRIVERS_CHAR_IPMI_IPMI_MSGHANDLER_CLEANUP_IPMI 	 0x00001801
#define DRIVERS_CHAR_IPMI_IPMI_WATCHDOG_IPMI_READ 	 0x00001802
#define DRIVERS_CHAR_JOYSTICK_GAMEPORT_WAIT_MS   	 0x00001901
#define DRIVERS_CHAR_JOYSTICK_SERPORT_SERPORT_LDISC_READ 	 0x00001902
#define DRIVERS_CHAR_JOYSTICK_NS558_WAIT_MS      	 0x00001903
#define DRIVERS_CHAR_JOYSTICK_LIGHTNING_WAIT_MS  	 0x00001904
#define DRIVERS_CHAR_JOYSTICK_PCIGAME_WAIT_MS    	 0x00001905
#define DRIVERS_CHAR_JOYSTICK_CS461X_WAIT_MS     	 0x00001906
#define DRIVERS_CHAR_JOYSTICK_EMU10K1_GP_WAIT_MS 	 0x00001907
#define DRIVERS_CHAR_JOYSTICK_IFORCE_WAIT_MS     	 0x00001908
#define DRIVERS_CHAR_JOYSTICK_IFORCE_SEND_PACKET 	 0x00001909
#define DRIVERS_CHAR_JOYSTICK_IFORCE_GET_ID_PACKET 	 0x0000190a
#define DRIVERS_CHAR_JOYSTICK_ANALOG_WAIT_MS     	 0x0000190b
#define DRIVERS_CHAR_JOYSTICK_A3D_WAIT_MS        	 0x0000190c
#define DRIVERS_CHAR_JOYSTICK_ADI_WAIT_MS        	 0x0000190d
#define DRIVERS_CHAR_JOYSTICK_COBRA_WAIT_MS      	 0x0000190e
#define DRIVERS_CHAR_JOYSTICK_GF2K_WAIT_MS       	 0x0000190f
#define DRIVERS_CHAR_JOYSTICK_GRIP_WAIT_MS       	 0x00001910
#define DRIVERS_CHAR_JOYSTICK_INTERACT_WAIT_MS   	 0x00001911
#define DRIVERS_CHAR_JOYSTICK_TMDC_WAIT_MS       	 0x00001912
#define DRIVERS_CHAR_JOYSTICK_SIDEWINDER_WAIT_MS 	 0x00001913
#define DRIVERS_CHAR_MWAVE_3780I_PACEMSAACCESS   	 0x00001a01
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_NETIF_POLL_DISABLE 	 0x00001b01
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_WAIT_EVENTS 	 0x00001b02
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MODEM_INPUT_WAIT 	 0x00001b03
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MGSLPC_CLOSE 	 0x00001b04
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MGSLPC_WAIT_UNTIL_SENT 	 0x00001b05
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_BLOCK_TIL_READY 	 0x00001b06
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_IRQ_TEST 	 0x00001b07
#define DRIVERS_CHAR_RIO_RIO_LINUX_RIODELAY      	 0x00001c01
#define DRIVERS_CHAR_RIO_RIO_LINUX_RIODELAY_NI   	 0x00001c02
#define DRIVERS_CHAR_MEM_READ_ZERO_PAGEALIGNED   	 0x00001d01
#define DRIVERS_CHAR_TTY_IO_DO_TTY_WRITE         	 0x00001e01
#define DRIVERS_CHAR_TTY_IO_RELEASE_DEV          	 0x00001e02
#define DRIVERS_CHAR_TTY_IO_TTY_OPEN             	 0x00001e03
#define DRIVERS_CHAR_TTY_IO_SEND_BREAK           	 0x00001e04
#define DRIVERS_CHAR_N_TTY_READ_CHAN             	 0x00001f01
#define DRIVERS_CHAR_N_TTY_WRITE_CHAN            	 0x00001f02
#define DRIVERS_CHAR_TTY_IOCTL_TTY_WAIT_UNTIL_SENT 	 0x00002001
#define DRIVERS_CHAR_RANDOM_EXTRACT_ENTROPY      	 0x00002101
#define DRIVERS_CHAR_RANDOM_RANDOM_READ          	 0x00002102
#define DRIVERS_CHAR_VT_VT_WAITACTIVE            	 0x00002201
#define DRIVERS_CHAR_SELECTION_PASTE_SELECTION   	 0x00002301
#define DRIVERS_CHAR_SERIAL_RS_CLOSE             	 0x00002401
#define DRIVERS_CHAR_SERIAL_RS_WAIT_UNTIL_SENT   	 0x00002402
#define DRIVERS_CHAR_SERIAL_BLOCK_TIL_READY      	 0x00002403
#define DRIVERS_CHAR_SERIAL_PCI_XIRCOM_FN        	 0x00002404
#define DRIVERS_CHAR_PC_KEYB_READ_AUX            	 0x00002501
#define DRIVERS_CHAR_ROCKET_BLOCK_TIL_READY      	 0x00002601
#define DRIVERS_CHAR_ROCKET_RP_CLOSE             	 0x00002602
#define DRIVERS_CHAR_ROCKET_RP_WAIT_UNTIL_SENT   	 0x00002603
#define DRIVERS_CHAR_MXSER_MXSER_CLOSE           	 0x00002701
#define DRIVERS_CHAR_MXSER_MXSER_BLOCK_TIL_READY 	 0x00002702
#define DRIVERS_CHAR_MXSER_MXSER_SEND_BREAK      	 0x00002703
#define DRIVERS_CHAR_MOXA_MOXA_CLOSE             	 0x00002801
#define DRIVERS_CHAR_MOXA_BLOCK_TILL_READY       	 0x00002802
#define DRIVERS_CHAR_EPCA_PC_CLOSE               	 0x00002901
#define DRIVERS_CHAR_EPCA_BLOCK_TIL_READY        	 0x00002902
#define DRIVERS_CHAR_CYCLADES_BLOCK_TIL_READY    	 0x00002a01
#define DRIVERS_CHAR_CYCLADES_CY_WAIT_UNTIL_SENT 	 0x00002a02
#define DRIVERS_CHAR_CYCLADES_CY_CLOSE           	 0x00002a03
#define DRIVERS_CHAR_STALLION_STL_DELAY          	 0x00002b01
#define DRIVERS_CHAR_ISTALLION_STLI_DELAY        	 0x00002c01
#define DRIVERS_CHAR_RISCOM8_BLOCK_TIL_READY     	 0x00002d01
#define DRIVERS_CHAR_RISCOM8_RC_CLOSE            	 0x00002d02
#define DRIVERS_CHAR_ESP_RS_CLOSE                	 0x00002e01
#define DRIVERS_CHAR_ESP_RS_WAIT_UNTIL_SENT      	 0x00002e02
#define DRIVERS_CHAR_ESP_BLOCK_TIL_READY         	 0x00002e03
#define DRIVERS_CHAR_SYNCLINK_NETIF_POLL_DISABLE 	 0x00002f01
#define DRIVERS_CHAR_SYNCLINK_MGSL_WAIT_EVENT    	 0x00002f02
#define DRIVERS_CHAR_SYNCLINK_MODEM_INPUT_WAIT   	 0x00002f03
#define DRIVERS_CHAR_SYNCLINK_MGSL_CLOSE         	 0x00002f04
#define DRIVERS_CHAR_SYNCLINK_MGSL_WAIT_UNTIL_SENT 	 0x00002f05
#define DRIVERS_CHAR_SYNCLINK_BLOCK_TIL_READY    	 0x00002f06
#define DRIVERS_CHAR_SYNCLINK_MGSL_IRQ_TEST      	 0x00002f07
#define DRIVERS_CHAR_SYNCLINKMP_NETIF_POLL_DISABLE 	 0x00003001
#define DRIVERS_CHAR_SYNCLINKMP_CLOSE            	 0x00003002
#define DRIVERS_CHAR_SYNCLINKMP_WAIT_UNTIL_SENT  	 0x00003003
#define DRIVERS_CHAR_SYNCLINKMP_WAIT_MGSL_EVENT  	 0x00003004
#define DRIVERS_CHAR_SYNCLINKMP_MODEM_INPUT_WAIT 	 0x00003005
#define DRIVERS_CHAR_SYNCLINKMP_BLOCK_TIL_READY  	 0x00003006
#define DRIVERS_CHAR_SYNCLINKMP_IRQ_TEST         	 0x00003007
#define DRIVERS_CHAR_SYNCLINKMP_LOOPBACK_TEST    	 0x00003008
#define DRIVERS_CHAR_N_HDLC_N_HDLC_TTY_WRITE     	 0x00003101
#define DRIVERS_CHAR_SPECIALIX_BLOCK_TIL_READY   	 0x00003201
#define DRIVERS_CHAR_SPECIALIX_SX_CLOSE          	 0x00003202
#define DRIVERS_CHAR_SX_SX_CLOSE                 	 0x00003301
#define DRIVERS_CHAR_GENERIC_SERIAL_GS_WAIT_TX_FLUSHED 	 0x00003401
#define DRIVERS_CHAR_GENERIC_SERIAL_GS_BLOCK_TIL_READY 	 0x00003402
#define DRIVERS_CHAR_GENERIC_SERIAL_GS_CLOSE     	 0x00003403
#define DRIVERS_CHAR_LP_LP_WRITE                 	 0x00003501
#define DRIVERS_CHAR_LP_LP_READ                  	 0x00003502
#define DRIVERS_CHAR_TIPAR_PUT_TI_PARALLEL       	 0x00003601
#define DRIVERS_CHAR_TIPAR_GET_TI_PARALLEL       	 0x00003602
#define DRIVERS_CHAR_TIPAR_TIPAR_READ            	 0x00003603
#define DRIVERS_CHAR_BUSMOUSE_BUSMOUSE_READ      	 0x00003701
#define DRIVERS_CHAR_DTLK_DTLK_CLEANUP           	 0x00003801
#define DRIVERS_CHAR_DTLK_DTLK_DELAY             	 0x00003802
#define DRIVERS_CHAR_N_R3964_R3964_READ          	 0x00003901
#define DRIVERS_CHAR_APPLICOM_AC_WRITE           	 0x00003a01
#define DRIVERS_CHAR_APPLICOM_AC_READ            	 0x00003a02
#define DRIVERS_CHAR_SONYPI_SONYPI_CAMERA_ON     	 0x00003b01
#define DRIVERS_CHAR_SONYPI_SONYPI_MISC_READ     	 0x00003b02
#define DRIVERS_CHAR_QPMOUSE_POLL_QP_STATUS      	 0x00003c01
#define DRIVERS_CHAR_QPMOUSE_READ_QP             	 0x00003c02
#define DRIVERS_CHAR_MK712_MK712_READ            	 0x00003d01
#define DRIVERS_CHAR_RTC_RTC_READ                	 0x00003e01
#define DRIVERS_CHAR_I810_RNG_RNG_DEV_READ       	 0x00003f01
#define DRIVERS_CHAR_AMD768_RNG_RNG_DEV_READ     	 0x00004001
#define DRIVERS_CHAR_HW_RANDOM_RNG_DEV_READ      	 0x00004101
#define DRIVERS_CHAR_AMD76X_PM_AMD76X_PM_CLEANUP 	 0x00004201
#define DRIVERS_CHAR_TPQIC02_WAIT_FOR_READY      	 0x00004301
#define DRIVERS_CHAR_TPQIC02_RDSTATUS            	 0x00004302
#define DRIVERS_CHAR_TPQIC02_DO_IOCTL_CMD        	 0x00004303
#define DRIVERS_CHAR_PPDEV_PP_READ               	 0x00004401
#define DRIVERS_CHAR_PPDEV_PP_WRITE              	 0x00004402
#define DRIVERS_CHAR_PCWD_CHECK_ISA_CARD         	 0x00004501
#define DRIVERS_I2C_I2C_ALGO_BIT_SCLHI           	 0x00004601
#define DRIVERS_I2C_I2C_ALGO_PCF_PCF_SLEEP       	 0x00004602
#define DRIVERS_IDE_LEGACY_IDE_CS_IDE_CONFIG     	 0x00004701
#define DRIVERS_IDE_IDE_IDE_DELAY_50MS           	 0x00004702
#define DRIVERS_IDE_IDE_DISK_IDE_DISK_SUSPEND    	 0x00004703
#define DRIVERS_IDE_IDE_CD_CDROM_SLEEP           	 0x00004704
#define DRIVERS_IDE_IDE_TAPE_IDETAPE_WAIT_READY  	 0x00004705
#define DRIVERS_IEEE1394_NODEMGR_NODEMGR_READ_QUADLET 	 0x00004801
#define DRIVERS_IEEE1394_NODEMGR_READ_BUSINFO_BLOCK 	 0x00004802
#define DRIVERS_IEEE1394_NODEMGR_NODEMGR_HOST_THREAD 	 0x00004803
#define DRIVERS_IEEE1394_ISO_HPSB_ISO_XMIT_SYNC  	 0x00004804
#define DRIVERS_IEEE1394_SBP2_SBP2UTIL_DOWN_TIMEOUT 	 0x00004805
#define DRIVERS_IEEE1394_SBP2_SBP2_START_DEVICE  	 0x00004806
#define DRIVERS_IEEE1394_DV1394_DV1394_WRITE     	 0x00004807
#define DRIVERS_IEEE1394_DV1394_DV1394_READ      	 0x00004808
#define DRIVERS_IEEE1394_DV1394_DV1394_IOCTL     	 0x00004809
#define DRIVERS_IEEE1394_ETH1394_NETIF_POLL_DISABLE 	 0x0000480a
#define DRIVERS_IEEE1394_AMDTP_OHCI1394_STOP_IT_CTX 	 0x0000480b
#define DRIVERS_IEEE1394_AMDTP_STREAM_FREE       	 0x0000480c
#define DRIVERS_IEEE1394_AMDTP_AMDTP_WRITE       	 0x0000480d
#define DRIVERS_INPUT_MOUSEDEV_MOUSEDEV_READ     	 0x00004901
#define DRIVERS_INPUT_JOYDEV_JOYDEV_READ         	 0x00004a01
#define DRIVERS_INPUT_EVDEV_EVDEV_READ           	 0x00004b01
#define DRIVERS_ISDN_ACT2000_ACT2000_ISA_ACT2000_ISA_DELAY 	 0x00004c01
#define DRIVERS_ISDN_AVMB1_KCAPI_OLD_CAPI_MANUFACTURER 	 0x00004c02
#define DRIVERS_ISDN_AVMB1_CAPI_NETIF_POLL_DISABLE 	 0x00004c03
#define DRIVERS_ISDN_AVMB1_CAPIDRV_NETIF_POLL_DISABLE 	 0x00004c04
#define DRIVERS_ISDN_AVMB1_B1_NETIF_POLL_DISABLE 	 0x00004c05
#define DRIVERS_ISDN_AVMB1_B1DMA_NETIF_POLL_DISABLE 	 0x00004c06
#define DRIVERS_ISDN_AVMB1_C4_NETIF_POLL_DISABLE 	 0x00004c07
#define DRIVERS_ISDN_EICON_COMMON_NETIF_POLL_DISABLE 	 0x00004c08
#define DRIVERS_ISDN_EICON_BRI_NETIF_POLL_DISABLE 	 0x00004c09
#define DRIVERS_ISDN_EICON_KPRINTF_NETIF_POLL_DISABLE 	 0x00004c0a
#define DRIVERS_ISDN_HISAX_CONFIG_NETIF_POLL_DISABLE 	 0x00004c0b
#define DRIVERS_ISDN_HISAX_CONFIG_INIT_CARD      	 0x00004c0c
#define DRIVERS_ISDN_HISAX_ISDNL1_NETIF_POLL_DISABLE 	 0x00004c0d
#define DRIVERS_ISDN_HISAX_TEI_NETIF_POLL_DISABLE 	 0x00004c0e
#define DRIVERS_ISDN_HISAX_ISDNL2_NETIF_POLL_DISABLE 	 0x00004c0f
#define DRIVERS_ISDN_HISAX_ISDNL3_NETIF_POLL_DISABLE 	 0x00004c10
#define DRIVERS_ISDN_HISAX_LMGR_NETIF_POLL_DISABLE 	 0x00004c11
#define DRIVERS_ISDN_HISAX_Q931_NETIF_POLL_DISABLE 	 0x00004c12
#define DRIVERS_ISDN_HISAX_CALLC_NETIF_POLL_DISABLE 	 0x00004c13
#define DRIVERS_ISDN_HISAX_FSM_NETIF_POLL_DISABLE 	 0x00004c14
#define DRIVERS_ISDN_HISAX_AMD7930_FN_NETIF_POLL_DISABLE 	 0x00004c15
#define DRIVERS_ISDN_HISAX_ARCOFI_NETIF_POLL_DISABLE 	 0x00004c16
#define DRIVERS_ISDN_HISAX_ASUSCOM_NETIF_POLL_DISABLE 	 0x00004c17
#define DRIVERS_ISDN_HISAX_ASUSCOM_RESET_ASUSCOM 	 0x00004c18
#define DRIVERS_ISDN_HISAX_AVM_A1_NETIF_POLL_DISABLE 	 0x00004c19
#define DRIVERS_ISDN_HISAX_AVM_A1P_NETIF_POLL_DISABLE 	 0x00004c1a
#define DRIVERS_ISDN_HISAX_AVM_PCI_NETIF_POLL_DISABLE 	 0x00004c1b
#define DRIVERS_ISDN_HISAX_AVM_PCI_RESET_AVMPCIPNP 	 0x00004c1c
#define DRIVERS_ISDN_HISAX_BKM_A4T_NETIF_POLL_DISABLE 	 0x00004c1d
#define DRIVERS_ISDN_HISAX_BKM_A4T_RESET_BKM     	 0x00004c1e
#define DRIVERS_ISDN_HISAX_BKM_A8_NETIF_POLL_DISABLE 	 0x00004c1f
#define DRIVERS_ISDN_HISAX_BKM_A8_RESET_BKM      	 0x00004c20
#define DRIVERS_ISDN_HISAX_DIVA_NETIF_POLL_DISABLE 	 0x00004c21
#define DRIVERS_ISDN_HISAX_DIVA_RESET_DIVA       	 0x00004c22
#define DRIVERS_ISDN_HISAX_ELSA_NETIF_POLL_DISABLE 	 0x00004c23
#define DRIVERS_ISDN_HISAX_ELSA_RESET_ELSA       	 0x00004c24
#define DRIVERS_ISDN_HISAX_ELSA_ELSA_CARD_MSG    	 0x00004c25
#define DRIVERS_ISDN_HISAX_ENTERNOW_PCI_NETIF_POLL_DISABLE 	 0x00004c26
#define DRIVERS_ISDN_HISAX_ENTERNOW_PCI_RESET_ENPCI 	 0x00004c27
#define DRIVERS_ISDN_HISAX_ENTERNOW_PCI_SETUP_ENTERNOW_PCI 	 0x00004c28
#define DRIVERS_ISDN_HISAX_GAZEL_NETIF_POLL_DISABLE 	 0x00004c29
#define DRIVERS_ISDN_HISAX_HFC_2BDS0_NETIF_POLL_DISABLE 	 0x00004c2a
#define DRIVERS_ISDN_HISAX_HFC_2BS0_NETIF_POLL_DISABLE 	 0x00004c2b
#define DRIVERS_ISDN_HISAX_HFC_PCI_NETIF_POLL_DISABLE 	 0x00004c2c
#define DRIVERS_ISDN_HISAX_HFC_PCI_RELEASE_IO_HFCPCI 	 0x00004c2d
#define DRIVERS_ISDN_HISAX_HFC_PCI_RESET_HFCPCI  	 0x00004c2e
#define DRIVERS_ISDN_HISAX_HFC_PCI_HFCPCI_CARD_MSG 	 0x00004c2f
#define DRIVERS_ISDN_HISAX_HFC_SX_NETIF_POLL_DISABLE 	 0x00004c30
#define DRIVERS_ISDN_HISAX_HFC_SX_RELEASE_IO_HFCSX 	 0x00004c31
#define DRIVERS_ISDN_HISAX_HFC_SX_RESET_HFCSX    	 0x00004c32
#define DRIVERS_ISDN_HISAX_HFC_SX_HFCSX_CARD_MSG 	 0x00004c33
#define DRIVERS_ISDN_HISAX_HFCSCARD_NETIF_POLL_DISABLE 	 0x00004c34
#define DRIVERS_ISDN_HISAX_HFCSCARD_RESET_HFCS   	 0x00004c35
#define DRIVERS_ISDN_HISAX_HFCSCARD_HFCS_CARD_MSG 	 0x00004c36
#define DRIVERS_ISDN_HISAX_HSCX_NETIF_POLL_DISABLE 	 0x00004c37
#define DRIVERS_ISDN_HISAX_ICC_NETIF_POLL_DISABLE 	 0x00004c38
#define DRIVERS_ISDN_HISAX_IPACX_NETIF_POLL_DISABLE 	 0x00004c39
#define DRIVERS_ISDN_HISAX_ISAC_NETIF_POLL_DISABLE 	 0x00004c3a
#define DRIVERS_ISDN_HISAX_ISAR_NETIF_POLL_DISABLE 	 0x00004c3b
#define DRIVERS_ISDN_HISAX_ISURF_NETIF_POLL_DISABLE 	 0x00004c3c
#define DRIVERS_ISDN_HISAX_ISURF_RESET_ISURF     	 0x00004c3d
#define DRIVERS_ISDN_HISAX_IX1_MICRO_NETIF_POLL_DISABLE 	 0x00004c3e
#define DRIVERS_ISDN_HISAX_JADE_NETIF_POLL_DISABLE 	 0x00004c3f
#define DRIVERS_ISDN_HISAX_L3_1TR6_NETIF_POLL_DISABLE 	 0x00004c40
#define DRIVERS_ISDN_HISAX_L3DSS1_NETIF_POLL_DISABLE 	 0x00004c41
#define DRIVERS_ISDN_HISAX_L3NI1_NETIF_POLL_DISABLE 	 0x00004c42
#define DRIVERS_ISDN_HISAX_MIC_NETIF_POLL_DISABLE 	 0x00004c43
#define DRIVERS_ISDN_HISAX_NETJET_NETIF_POLL_DISABLE 	 0x00004c44
#define DRIVERS_ISDN_HISAX_NICCY_NETIF_POLL_DISABLE 	 0x00004c45
#define DRIVERS_ISDN_HISAX_NJ_S_NETIF_POLL_DISABLE 	 0x00004c46
#define DRIVERS_ISDN_HISAX_NJ_S_RESET_NETJET_S   	 0x00004c47
#define DRIVERS_ISDN_HISAX_NJ_S_SETUP_NETJET_S   	 0x00004c48
#define DRIVERS_ISDN_HISAX_NJ_U_NETIF_POLL_DISABLE 	 0x00004c49
#define DRIVERS_ISDN_HISAX_NJ_U_RESET_NETJET_U   	 0x00004c4a
#define DRIVERS_ISDN_HISAX_NJ_U_SETUP_NETJET_U   	 0x00004c4b
#define DRIVERS_ISDN_HISAX_S0BOX_NETIF_POLL_DISABLE 	 0x00004c4c
#define DRIVERS_ISDN_HISAX_SAPHIR_NETIF_POLL_DISABLE 	 0x00004c4d
#define DRIVERS_ISDN_HISAX_SAPHIR_SAPHIR_RESET   	 0x00004c4e
#define DRIVERS_ISDN_HISAX_SEDLBAUER_NETIF_POLL_DISABLE 	 0x00004c4f
#define DRIVERS_ISDN_HISAX_SEDLBAUER_RESET_SEDLBAUER 	 0x00004c50
#define DRIVERS_ISDN_HISAX_SEDLBAUER_SETUP_SEDLBAUER 	 0x00004c51
#define DRIVERS_ISDN_HISAX_SPORTSTER_NETIF_POLL_DISABLE 	 0x00004c52
#define DRIVERS_ISDN_HISAX_SPORTSTER_RESET_SPORTSTER 	 0x00004c53
#define DRIVERS_ISDN_HISAX_TELEINT_NETIF_POLL_DISABLE 	 0x00004c54
#define DRIVERS_ISDN_HISAX_TELEINT_RESET_TELEINT 	 0x00004c55
#define DRIVERS_ISDN_HISAX_TELES0_NETIF_POLL_DISABLE 	 0x00004c56
#define DRIVERS_ISDN_HISAX_TELES3_NETIF_POLL_DISABLE 	 0x00004c57
#define DRIVERS_ISDN_HISAX_TELESPCI_NETIF_POLL_DISABLE 	 0x00004c58
#define DRIVERS_ISDN_HISAX_W6692_NETIF_POLL_DISABLE 	 0x00004c59
#define DRIVERS_ISDN_HISAX_W6692_RESETW6692      	 0x00004c5a
#define DRIVERS_ISDN_HISAX_ST5481_INIT_WAIT_MS   	 0x00004c5b
#define DRIVERS_ISDN_HISAX_ST5481_USB_WAIT_MS    	 0x00004c5c
#define DRIVERS_ISDN_HISAX_ST5481_D_WAIT_MS      	 0x00004c5d
#define DRIVERS_ISDN_HISAX_ST5481_D_NETIF_POLL_DISABLE 	 0x00004c5e
#define DRIVERS_ISDN_HISAX_ST5481_B_WAIT_MS      	 0x00004c5f
#define DRIVERS_ISDN_HISAX_ST5481_B_NETIF_POLL_DISABLE 	 0x00004c60
#define DRIVERS_ISDN_HISAX_HISAX_ISAC_NETIF_POLL_DISABLE 	 0x00004c61
#define DRIVERS_ISDN_HISAX_HISAX_FCPCIPNP_NETIF_POLL_DISABLE 	 0x00004c62
#define DRIVERS_ISDN_HISAX_HISAX_FCPCIPNP_FCPCI_INIT 	 0x00004c63
#define DRIVERS_ISDN_HISAX_HISAX_FCPCIPNP_FCPCIPNP_SETUP 	 0x00004c64
#define DRIVERS_ISDN_ICN_ICN_ICN_CHECK_LOADER    	 0x00004c65
#define DRIVERS_ISDN_ICN_ICN_ICN_LOADPROTO       	 0x00004c66
#define DRIVERS_ISDN_ICN_ICN_ICN_COMMAND         	 0x00004c67
#define DRIVERS_ISDN_ISDNLOOP_ISDNLOOP_ISDNLOOP_COMMAND 	 0x00004c68
#define DRIVERS_ISDN_SC_INIT_SC_INIT             	 0x00004c69
#define DRIVERS_ISDN_SC_INIT_IDENTIFY_BOARD      	 0x00004c6a
#define DRIVERS_ISDN_SC_MESSAGE_SEND_AND_RECEIVE 	 0x00004c6b
#define DRIVERS_ISDN_TPAM_TPAM_COMMANDS_TPAM_COMMAND_IOCTL_DSPRUN 	 0x00004c6c
#define DRIVERS_ISDN_ISDN_NET_NETIF_POLL_DISABLE 	 0x00004c6d
#define DRIVERS_ISDN_ISDN_TTY_NETIF_POLL_DISABLE 	 0x00004c6e
#define DRIVERS_ISDN_ISDN_TTY_ISDN_TTY_BLOCK_TIL_READY 	 0x00004c6f
#define DRIVERS_ISDN_ISDN_TTY_ISDN_TTY_CLOSE     	 0x00004c70
#define DRIVERS_ISDN_ISDN_V110_NETIF_POLL_DISABLE 	 0x00004c71
#define DRIVERS_ISDN_ISDN_COMMON_NETIF_POLL_DISABLE 	 0x00004c72
#define DRIVERS_ISDN_ISDN_PPP_NETIF_POLL_DISABLE 	 0x00004c73
#define DRIVERS_ISDN_ISDN_CONCAP_NETIF_POLL_DISABLE 	 0x00004c74
#define DRIVERS_ISDN_ISDN_X25IFACE_NETIF_POLL_DISABLE 	 0x00004c75
#define DRIVERS_ISDN_ISDN_AUDIO_NETIF_POLL_DISABLE 	 0x00004c76
#define DRIVERS_ISDN_ISDN_TTYFAX_NETIF_POLL_DISABLE 	 0x00004c77
#define DRIVERS_ISDN_ISDN_BSDCOMP_NETIF_POLL_DISABLE 	 0x00004c78
#define DRIVERS_MD_LINEAR_NETIF_POLL_DISABLE     	 0x00004d01
#define DRIVERS_MD_RAID0_NETIF_POLL_DISABLE      	 0x00004d02
#define DRIVERS_MD_RAID1_NETIF_POLL_DISABLE      	 0x00004d03
#define DRIVERS_MD_RAID1_RAID1_ALLOC_BH          	 0x00004d04
#define DRIVERS_MD_RAID1_RAID1_ALLOC_R1BH        	 0x00004d05
#define DRIVERS_MD_RAID1_RAID1_ALLOC_BUF         	 0x00004d06
#define DRIVERS_MD_RAID1_RAID1_MAKE_REQUEST      	 0x00004d07
#define DRIVERS_MD_RAID1_CLOSE_SYNC              	 0x00004d08
#define DRIVERS_MD_RAID1_RAID1_SYNC_REQUEST      	 0x00004d09
#define DRIVERS_MD_RAID5_NETIF_POLL_DISABLE      	 0x00004d0a
#define DRIVERS_MD_RAID5_GET_ACTIVE_STRIPE       	 0x00004d0b
#define DRIVERS_MD_XOR_NETIF_POLL_DISABLE        	 0x00004d0c
#define DRIVERS_MD_MULTIPATH_NETIF_POLL_DISABLE  	 0x00004d0d
#define DRIVERS_MD_MULTIPATH_MULTIPATH_ALLOC_MPBH 	 0x00004d0e
#define DRIVERS_MD_MD_NETIF_POLL_DISABLE         	 0x00004d0f
#define DRIVERS_MD_MD_FREE_MDDEV                 	 0x00004d10
#define DRIVERS_MD_MD_MD_THREAD                  	 0x00004d11
#define DRIVERS_MD_MD_MD_DO_SYNC                 	 0x00004d12
#define DRIVERS_MD_LVM_LVM_DO_VG_REMOVE          	 0x00004d13
#define DRIVERS_MEDIA_RADIO_RADIO_SF16FMI_FMI_SETFREQ 	 0x00004e01
#define DRIVERS_MEDIA_RADIO_RADIO_SF16FMI_FMI_GETSIGSTR 	 0x00004e02
#define DRIVERS_MEDIA_RADIO_RADIO_SF16FMR2_SLEEP_DELAY 	 0x00004e03
#define DRIVERS_MEDIA_RADIO_RADIO_CADET_CADET_GETRDS 	 0x00004e04
#define DRIVERS_MEDIA_RADIO_RADIO_CADET_CADET_SETFREQ 	 0x00004e05
#define DRIVERS_MEDIA_RADIO_RADIO_MAXIRADIO_SLEEP_125MS 	 0x00004e06
#define DRIVERS_MEDIA_RADIO_RADIO_AIMSLAB_SLEEP_DELAY 	 0x00004e07
#define DRIVERS_MEDIA_RADIO_RADIO_ZOLTRIX_SLEEP_DELAY 	 0x00004e08
#define DRIVERS_MEDIA_RADIO_MIROPCM20_RDS_RDS_F_READ 	 0x00004e09
#define DRIVERS_MEDIA_RADIO_RADIO_MAESTRO_SLEEP_125MS 	 0x00004e0a
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_READ 	 0x00004f01
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_WRITE 	 0x00004f02
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_THREAD 	 0x00004f03
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3410D_THREAD 	 0x00004f04
#define DRIVERS_MEDIA_VIDEO_SAA5249_JDELAY       	 0x00004f05
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QCAM_AWAIT_READY1 	 0x00004f06
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QCAM_AWAIT_READY2 	 0x00004f07
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QC_CAPTURE    	 0x00004f08
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_CALIBRATE 	 0x00004f09
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_WAITHAND  	 0x00004f0a
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_WAITHAND2 	 0x00004f0b
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_CAPTURE   	 0x00004f0c
#define DRIVERS_MEDIA_VIDEO_ZR36067_ZR36057_ENABLE_JPG 	 0x00004f0d
#define DRIVERS_MEDIA_VIDEO_ZR36067_DO_ZORAN_IOCTL 	 0x00004f0e
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CWIPE      	 0x00004f0f
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CREAD      	 0x00004f10
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CWRITE     	 0x00004f11
#define DRIVERS_MEDIA_VIDEO_STRADIS_IBM_SEND_COMMAND 	 0x00004f12
#define DRIVERS_MEDIA_VIDEO_STRADIS_INITIALIZE_CS4341 	 0x00004f13
#define DRIVERS_MEDIA_VIDEO_STRADIS_INITIALIZE_FPGA 	 0x00004f14
#define DRIVERS_MEDIA_VIDEO_CPIA_FETCH_FRAME     	 0x00004f15
#define DRIVERS_MEDIA_VIDEO_CPIA_PP_CPIA_PP_STREAMREAD 	 0x00004f16
#define DRIVERS_MEDIA_VIDEO_CPIA_USB_WAIT_MS     	 0x00004f17
#define DRIVERS_MEDIA_VIDEO_MEYE_WAIT_MS         	 0x00004f18
#define DRIVERS_MEDIA_VIDEO_MEYE_MEYE_DO_IOCTL   	 0x00004f19
#define DRIVERS_MEDIA_VIDEO_TUNER_3036_SET_TV_FREQ 	 0x00004f1a
#define DRIVERS_MEDIA_VIDEO_BTTV_CARDS_TEA5757_READ 	 0x00004f1b
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_SET_PLL  	 0x00004f1c
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_BTTV_CLOSE 	 0x00004f1d
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_BTTV_IOCTL 	 0x00004f1e
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_VBI_READ 	 0x00004f1f
#define DRIVERS_MEDIA_VIDEO_ZR36120_ZORAN_CLOSE  	 0x00004f20
#define DRIVERS_MEDIA_VIDEO_ZR36120_VBI_CLOSE    	 0x00004f21
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MAKEIOCREADY 	 0x00005001
#define DRIVERS_MESSAGE_FUSION_MPTBASE_SENDIOCINIT 	 0x00005002
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_DOWNLOADBOOT 	 0x00005003
#define DRIVERS_MESSAGE_FUSION_MPTBASE_KICKSTART 	 0x00005004
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_DIAG_RESET 	 0x00005005
#define DRIVERS_MESSAGE_FUSION_MPTBASE_SENDIOCRESET 	 0x00005006
#define DRIVERS_MESSAGE_FUSION_MPTBASE_WAITFORDOORBELLACK 	 0x00005007
#define DRIVERS_MESSAGE_FUSION_MPTBASE_WAITFORDOORBELLINT 	 0x00005008
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_CONFIG 	 0x00005009
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_RELEASE 	 0x0000500a
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_TASKMGMT_BH 	 0x0000500b
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DO_RAID 	 0x0000500c
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DO_CMD 	 0x0000500d
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DOMAINVALIDATION 	 0x0000500e
#define DRIVERS_MESSAGE_FUSION_MPTLAN_NETIF_POLL_DISABLE 	 0x0000500f
#define DRIVERS_MESSAGE_FUSION_MPTLAN_MPT_LAN_CLOSE 	 0x00005010
#define DRIVERS_MESSAGE_I2O_I2O_CORE_NETIF_POLL_DISABLE 	 0x00005101
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_DELETE_CONTROLLER 	 0x00005102
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_RELEASE_DEVICE 	 0x00005103
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_WAIT_MESSAGE 	 0x00005104
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_RESET_CONTROLLER 	 0x00005105
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_STATUS_GET 	 0x00005106
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_INIT_OUTBOUND_Q 	 0x00005107
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_POST_WAIT_MEM 	 0x00005108
#define DRIVERS_MESSAGE_I2O_I2O_BLOCK_I2O_BLOCK_EXIT 	 0x00005109
#define DRIVERS_MESSAGE_I2O_I2O_PROC_NETIF_POLL_DISABLE 	 0x0000510a
#define DRIVERS_MTD_CHIPS_AMD_FLASH_READ_ONE_CHIP 	 0x00005201
#define DRIVERS_MTD_CHIPS_AMD_FLASH_WRITE_ONE_WORD 	 0x00005202
#define DRIVERS_MTD_CHIPS_AMD_FLASH_ERASE_ONE_BLOCK 	 0x00005203
#define DRIVERS_MTD_CHIPS_AMD_FLASH_AMD_FLASH_SYNC 	 0x00005204
#define DRIVERS_MTD_CHIPS_CFI_PROBE_CFI_UDELAY   	 0x00005205
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_CFI_UDELAY 	 0x00005206
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_DO_READ_ONECHIP 	 0x00005207
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_DO_WRITE_BUFFER 	 0x00005208
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_DO_ERASE_ONEBLOCK 	 0x00005209
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_CFI_STAA_SYNC 	 0x0000520a
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_DO_LOCK_ONEBLOCK 	 0x0000520b
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0020_DO_UNLOCK_ONEBLOCK 	 0x0000520c
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_CFI_UDELAY 	 0x0000520d
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_READ_ONECHIP 	 0x0000520e
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_READ_SECSI_ONECHIP 	 0x0000520f
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_WRITE_ONEWORD 	 0x00005210
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_ERASE_CHIP 	 0x00005211
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_ERASE_ONEBLOCK 	 0x00005212
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_CFI_AMDSTD_SYNC 	 0x00005213
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_CFI_UDELAY 	 0x00005214
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_POINT_ONECHIP 	 0x00005215
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_READ_ONECHIP 	 0x00005216
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_CFI_INTELEXT_READ_PROT_REG 	 0x00005217
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_WRITE_ONEWORD 	 0x00005218
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_WRITE_BUFFER 	 0x00005219
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_ERASE_ONEBLOCK 	 0x0000521a
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_CFI_INTELEXT_SYNC 	 0x0000521b
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_XXLOCK_ONEBLOCK 	 0x0000521c
#define DRIVERS_MTD_CHIPS_GEN_PROBE_CFI_UDELAY   	 0x0000521d
#define DRIVERS_MTD_CHIPS_JEDEC_PROBE_CFI_UDELAY 	 0x0000521e
#define DRIVERS_MTD_CHIPS_SHARP_CFI_UDELAY       	 0x0000521f
#define DRIVERS_MTD_CHIPS_SHARP_SHARP_WAIT       	 0x00005220
#define DRIVERS_MTD_CHIPS_SHARP_SHARP_DO_WAIT_FOR_READY 	 0x00005221
#define DRIVERS_MTD_DEVICES_DOC1000_FLASHCARD_WRITE 	 0x00005222
#define DRIVERS_MTD_DEVICES_DOC2000__DOC_WAITREADY 	 0x00005223
#define DRIVERS_MTD_MAPS_NETTEL_CFI_UDELAY       	 0x00005224
#define DRIVERS_MTD_MAPS_NETTEL_NETTEL_ERASECONFIG 	 0x00005225
#define DRIVERS_MTD_MAPS_SCB2_FLASH_CFI_UDELAY   	 0x00005226
#define DRIVERS_MTD_NAND_NAND_NAND_GET_CHIP      	 0x00005227
#define DRIVERS_MTD_NAND_NAND_NAND_ERASE         	 0x00005228
#define DRIVERS_MTD_NAND_NAND_NAND_SYNC          	 0x00005229
#define DRIVERS_MTD_MTDCONCAT_CONCAT_DEV_ERASE   	 0x0000522a
#define DRIVERS_MTD_MTDCHAR_MTD_IOCTL            	 0x0000522b
#define DRIVERS_MTD_MTDBLOCK_ERASE_WRITE         	 0x0000522c
#define DRIVERS_MTD_MTDBLOCK_MTDBLOCK_THREAD     	 0x0000522d
#define DRIVERS_NET_APPLETALK_IPDDP_NETIF_POLL_DISABLE 	 0x00005301
#define DRIVERS_NET_APPLETALK_COPS_NETIF_POLL_DISABLE 	 0x00005302
#define DRIVERS_NET_APPLETALK_COPS_COPS_RESET    	 0x00005303
#define DRIVERS_NET_APPLETALK_COPS_COPS_NODEID   	 0x00005304
#define DRIVERS_NET_APPLETALK_LTPC_NETIF_POLL_DISABLE 	 0x00005305
#define DRIVERS_NET_APPLETALK_LTPC_LTPC_CLEANUP  	 0x00005306
#define DRIVERS_NET_ARCNET_ARCNET_NETIF_POLL_DISABLE 	 0x00005307
#define DRIVERS_NET_ARCNET_RFC1201_NETIF_POLL_DISABLE 	 0x00005308
#define DRIVERS_NET_ARCNET_RFC1051_NETIF_POLL_DISABLE 	 0x00005309
#define DRIVERS_NET_ARCNET_ARC_RAWMODE_NETIF_POLL_DISABLE 	 0x0000530a
#define DRIVERS_NET_ARCNET_COM90XX_NETIF_POLL_DISABLE 	 0x0000530b
#define DRIVERS_NET_ARCNET_COM90IO_NETIF_POLL_DISABLE 	 0x0000530c
#define DRIVERS_NET_ARCNET_ARC_RIMI_NETIF_POLL_DISABLE 	 0x0000530d
#define DRIVERS_NET_ARCNET_COM20020_NETIF_POLL_DISABLE 	 0x0000530e
#define DRIVERS_NET_ARCNET_COM20020_ISA_NETIF_POLL_DISABLE 	 0x0000530f
#define DRIVERS_NET_ARCNET_COM20020_PCI_NETIF_POLL_DISABLE 	 0x00005310
#define DRIVERS_NET_BONDING_BOND_MAIN_NETIF_POLL_DISABLE 	 0x00005311
#define DRIVERS_NET_BONDING_BOND_3AD_NETIF_POLL_DISABLE 	 0x00005312
#define DRIVERS_NET_BONDING_BOND_ALB_NETIF_POLL_DISABLE 	 0x00005313
#define DRIVERS_NET_E100_E100_MAIN_NETIF_POLL_DISABLE 	 0x00005314
#define DRIVERS_NET_E100_E100_MAIN_E100_TCO_WORKAROUND 	 0x00005315
#define DRIVERS_NET_E100_E100_MAIN_E100_SELFTEST 	 0x00005316
#define DRIVERS_NET_E100_E100_MAIN_E100_ETHTOOL_LED_BLINK 	 0x00005317
#define DRIVERS_NET_E100_E100_CONFIG_NETIF_POLL_DISABLE 	 0x00005318
#define DRIVERS_NET_E100_E100_PHY_NETIF_POLL_DISABLE 	 0x00005319
#define DRIVERS_NET_E100_E100_PHY_E100_PHY_RESET 	 0x0000531a
#define DRIVERS_NET_E100_E100_EEPROM_NETIF_POLL_DISABLE 	 0x0000531b
#define DRIVERS_NET_E100_E100_TEST_NETIF_POLL_DISABLE 	 0x0000531c
#define DRIVERS_NET_E100_E100_TEST_E100_DIAG_CONFIG_LOOPBACK 	 0x0000531d
#define DRIVERS_NET_E100_E100_TEST_E100_CABLE_DIAG 	 0x0000531e
#define DRIVERS_NET_E1000_E1000_MAIN_NETIF_POLL_DISABLE 	 0x0000531f
#define DRIVERS_NET_E1000_E1000_HW_E1000_PHY_INIT_SCRIPT 	 0x00005320
#define DRIVERS_NET_E1000_E1000_HW_E1000_RESET_HW 	 0x00005321
#define DRIVERS_NET_E1000_E1000_HW_E1000_INIT_HW 	 0x00005322
#define DRIVERS_NET_E1000_E1000_HW_E1000_SETUP_FIBER_SERDES_LINK 	 0x00005323
#define DRIVERS_NET_E1000_E1000_HW_E1000_SETUP_COPPER_LINK 	 0x00005324
#define DRIVERS_NET_E1000_E1000_HW_E1000_PHY_FORCE_SPEED_DUPLEX 	 0x00005325
#define DRIVERS_NET_E1000_E1000_HW_E1000_WAIT_AUTONEG 	 0x00005326
#define DRIVERS_NET_E1000_E1000_HW_E1000_PHY_HW_RESET 	 0x00005327
#define DRIVERS_NET_E1000_E1000_HW_E1000_WRITE_EEPROM 	 0x00005328
#define DRIVERS_NET_E1000_E1000_ETHTOOL_NETIF_POLL_DISABLE 	 0x00005329
#define DRIVERS_NET_E1000_E1000_ETHTOOL_E1000_INTR_TEST 	 0x0000532a
#define DRIVERS_NET_E1000_E1000_ETHTOOL_E1000_RUN_LOOPBACK_TEST 	 0x0000532b
#define DRIVERS_NET_E1000_E1000_ETHTOOL_E1000_ETHTOOL_LED_BLINK 	 0x0000532c
#define DRIVERS_NET_E1000_E1000_PARAM_NETIF_POLL_DISABLE 	 0x0000532d
#define DRIVERS_NET_FC_IPH5526_NETIF_POLL_DISABLE 	 0x0000532e
#define DRIVERS_NET_IRDA_IRTTY_NETIF_POLL_DISABLE 	 0x0000532f
#define DRIVERS_NET_IRDA_IRPORT_NETIF_POLL_DISABLE 	 0x00005330
#define DRIVERS_NET_IRDA_IRDA_USB_NETIF_POLL_DISABLE 	 0x00005331
#define DRIVERS_NET_IRDA_IRDA_USB_WAIT_MS        	 0x00005332
#define DRIVERS_NET_IRDA_NSC_IRCC_NETIF_POLL_DISABLE 	 0x00005333
#define DRIVERS_NET_IRDA_W83977AF_IR_NETIF_POLL_DISABLE 	 0x00005334
#define DRIVERS_NET_IRDA_TOSHOBOE_NETIF_POLL_DISABLE 	 0x00005335
#define DRIVERS_NET_IRDA_DONAUBOE_NETIF_POLL_DISABLE 	 0x00005336
#define DRIVERS_NET_IRDA_SMC_IRCC_NETIF_POLL_DISABLE 	 0x00005337
#define DRIVERS_NET_IRDA_ALI_IRCC_NETIF_POLL_DISABLE 	 0x00005338
#define DRIVERS_NET_IRDA_VLSI_IR_NETIF_POLL_DISABLE 	 0x00005339
#define DRIVERS_NET_IRDA_ESI_NETIF_POLL_DISABLE  	 0x0000533a
#define DRIVERS_NET_IRDA_TEKRAM_NETIF_POLL_DISABLE 	 0x0000533b
#define DRIVERS_NET_IRDA_ACTISYS_NETIF_POLL_DISABLE 	 0x0000533c
#define DRIVERS_NET_IRDA_GIRBIL_NETIF_POLL_DISABLE 	 0x0000533d
#define DRIVERS_NET_IRDA_LITELINK_NETIF_POLL_DISABLE 	 0x0000533e
#define DRIVERS_NET_IRDA_OLD_BELKIN_NETIF_POLL_DISABLE 	 0x0000533f
#define DRIVERS_NET_IRDA_MCP2120_NETIF_POLL_DISABLE 	 0x00005340
#define DRIVERS_NET_IRDA_ACT200L_NETIF_POLL_DISABLE 	 0x00005341
#define DRIVERS_NET_IRDA_MA600_NETIF_POLL_DISABLE 	 0x00005342
#define DRIVERS_NET_PCMCIA_3C589_CS_NETIF_POLL_DISABLE 	 0x00005343
#define DRIVERS_NET_PCMCIA_3C574_CS_NETIF_POLL_DISABLE 	 0x00005344
#define DRIVERS_NET_PCMCIA_FMVJ18X_CS_NETIF_POLL_DISABLE 	 0x00005345
#define DRIVERS_NET_PCMCIA_NMCLAN_CS_NETIF_POLL_DISABLE 	 0x00005346
#define DRIVERS_NET_PCMCIA_PCNET_CS_NETIF_POLL_DISABLE 	 0x00005347
#define DRIVERS_NET_PCMCIA_SMC91C92_CS_NETIF_POLL_DISABLE 	 0x00005348
#define DRIVERS_NET_PCMCIA_XIRC2PS_CS_NETIF_POLL_DISABLE 	 0x00005349
#define DRIVERS_NET_PCMCIA_XIRC2PS_CS_BUSY_LOOP  	 0x0000534a
#define DRIVERS_NET_PCMCIA_COM20020_CS_NETIF_POLL_DISABLE 	 0x0000534b
#define DRIVERS_NET_PCMCIA_AXNET_CS_NETIF_POLL_DISABLE 	 0x0000534c
#define DRIVERS_NET_PCMCIA_RAY_CS_NETIF_POLL_DISABLE 	 0x0000534d
#define DRIVERS_NET_PCMCIA_NETWAVE_CS_NETIF_POLL_DISABLE 	 0x0000534e
#define DRIVERS_NET_PCMCIA_WAVELAN_CS_NETIF_POLL_DISABLE 	 0x0000534f
#define DRIVERS_NET_PCMCIA_AIRONET4500_CS_NETIF_POLL_DISABLE 	 0x00005350
#define DRIVERS_NET_PCMCIA_XIRCOM_TULIP_CB_NETIF_POLL_DISABLE 	 0x00005351
#define DRIVERS_NET_PCMCIA_XIRCOM_CB_NETIF_POLL_DISABLE 	 0x00005352
#define DRIVERS_NET_SK98LIN_SKGE_NETIF_POLL_DISABLE 	 0x00005353
#define DRIVERS_NET_SK98LIN_SKDIM_NETIF_POLL_DISABLE 	 0x00005354
#define DRIVERS_NET_SK98LIN_SKADDR_NETIF_POLL_DISABLE 	 0x00005355
#define DRIVERS_NET_SK98LIN_SKGEHWT_NETIF_POLL_DISABLE 	 0x00005356
#define DRIVERS_NET_SK98LIN_SKGEINIT_NETIF_POLL_DISABLE 	 0x00005357
#define DRIVERS_NET_SK98LIN_SKGEPNMI_NETIF_POLL_DISABLE 	 0x00005358
#define DRIVERS_NET_SK98LIN_SKGESIRQ_NETIF_POLL_DISABLE 	 0x00005359
#define DRIVERS_NET_SK98LIN_SKI2C_NETIF_POLL_DISABLE 	 0x0000535a
#define DRIVERS_NET_SK98LIN_SKLM80_NETIF_POLL_DISABLE 	 0x0000535b
#define DRIVERS_NET_SK98LIN_SKQUEUE_NETIF_POLL_DISABLE 	 0x0000535c
#define DRIVERS_NET_SK98LIN_SKRLMT_NETIF_POLL_DISABLE 	 0x0000535d
#define DRIVERS_NET_SK98LIN_SKTIMER_NETIF_POLL_DISABLE 	 0x0000535e
#define DRIVERS_NET_SK98LIN_SKVPD_NETIF_POLL_DISABLE 	 0x0000535f
#define DRIVERS_NET_SK98LIN_SKXMAC2_NETIF_POLL_DISABLE 	 0x00005360
#define DRIVERS_NET_SK98LIN_SKPROC_NETIF_POLL_DISABLE 	 0x00005361
#define DRIVERS_NET_SK98LIN_SKCSUM_NETIF_POLL_DISABLE 	 0x00005362
#define DRIVERS_NET_TOKENRING_IBMTR_NETIF_POLL_DISABLE 	 0x00005363
#define DRIVERS_NET_TOKENRING_IBMTR_TOK_INIT_CARD 	 0x00005364
#define DRIVERS_NET_TOKENRING_IBMTR_TOK_OPEN     	 0x00005365
#define DRIVERS_NET_TOKENRING_OLYMPIC_NETIF_POLL_DISABLE 	 0x00005366
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_INIT 	 0x00005367
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_OPEN 	 0x00005368
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_CLOSE 	 0x00005369
#define DRIVERS_NET_TOKENRING_LANSTREAMER_NETIF_POLL_DISABLE 	 0x0000536a
#define DRIVERS_NET_TOKENRING_LANSTREAMER_STREAMER_RESET 	 0x0000536b
#define DRIVERS_NET_TOKENRING_SMCTR_NETIF_POLL_DISABLE 	 0x0000536c
#define DRIVERS_NET_TOKENRING_3C359_NETIF_POLL_DISABLE 	 0x0000536d
#define DRIVERS_NET_TOKENRING_3C359_XL_HW_RESET  	 0x0000536e
#define DRIVERS_NET_TOKENRING_3C359_XL_OPEN_HW   	 0x0000536f
#define DRIVERS_NET_TOKENRING_3C359_XL_CLOSE     	 0x00005370
#define DRIVERS_NET_TULIP_EEPROM_NETIF_POLL_DISABLE 	 0x00005371
#define DRIVERS_NET_TULIP_INTERRUPT_NETIF_POLL_DISABLE 	 0x00005372
#define DRIVERS_NET_TULIP_MEDIA_NETIF_POLL_DISABLE 	 0x00005373
#define DRIVERS_NET_TULIP_TIMER_NETIF_POLL_DISABLE 	 0x00005374
#define DRIVERS_NET_TULIP_TULIP_CORE_NETIF_POLL_DISABLE 	 0x00005375
#define DRIVERS_NET_TULIP_21142_NETIF_POLL_DISABLE 	 0x00005376
#define DRIVERS_NET_TULIP_PNIC_NETIF_POLL_DISABLE 	 0x00005377
#define DRIVERS_NET_TULIP_PNIC2_NETIF_POLL_DISABLE 	 0x00005378
#define DRIVERS_NET_WAN_8253X_8253XINI_NETIF_POLL_DISABLE 	 0x00005379
#define DRIVERS_NET_WAN_8253X_8253XNET_NETIF_POLL_DISABLE 	 0x0000537a
#define DRIVERS_NET_WAN_8253X_8253XSYN_NETIF_POLL_DISABLE 	 0x0000537b
#define DRIVERS_NET_WAN_8253X_8253XSYN_SAB8253X_CLOSES 	 0x0000537c
#define DRIVERS_NET_WAN_8253X_8253XDBG_NETIF_POLL_DISABLE 	 0x0000537d
#define DRIVERS_NET_WAN_8253X_8253XTTY_NETIF_POLL_DISABLE 	 0x0000537e
#define DRIVERS_NET_WAN_8253X_8253XTTY_SAB8253X_CLOSE 	 0x0000537f
#define DRIVERS_NET_WAN_8253X_8253XCHR_NETIF_POLL_DISABLE 	 0x00005380
#define DRIVERS_NET_WAN_8253X_8253XCHR_SAB8253X_BLOCK_TIL_READYC 	 0x00005381
#define DRIVERS_NET_WAN_8253X_8253XINT_NETIF_POLL_DISABLE 	 0x00005382
#define DRIVERS_NET_WAN_8253X_AMCC5920_NETIF_POLL_DISABLE 	 0x00005383
#define DRIVERS_NET_WAN_8253X_8253XMCS_NETIF_POLL_DISABLE 	 0x00005384
#define DRIVERS_NET_WAN_8253X_8253XUTL_NETIF_POLL_DISABLE 	 0x00005385
#define DRIVERS_NET_WAN_8253X_8253XUTL_SAB8253X_BLOCK_TIL_READY 	 0x00005386
#define DRIVERS_NET_WAN_8253X_8253XUTL_SAB8253X_WAIT_UNTIL_SENT 	 0x00005387
#define DRIVERS_NET_WAN_LMC_LMC_DEBUG_NETIF_POLL_DISABLE 	 0x00005388
#define DRIVERS_NET_WAN_LMC_LMC_MEDIA_NETIF_POLL_DISABLE 	 0x00005389
#define DRIVERS_NET_WAN_LMC_LMC_MAIN_NETIF_POLL_DISABLE 	 0x0000538a
#define DRIVERS_NET_WAN_LMC_LMC_PROTO_NETIF_POLL_DISABLE 	 0x0000538b
#define DRIVERS_NET_WAN_SYNCPPP_NETIF_POLL_DISABLE 	 0x0000538c
#define DRIVERS_NET_WAN_FARSYNC_NETIF_POLL_DISABLE 	 0x0000538d
#define DRIVERS_NET_WAN_FARSYNC_FST_ISSUE_CMD    	 0x0000538e
#define DRIVERS_NET_WAN_X25_ASY_NETIF_POLL_DISABLE 	 0x0000538f
#define DRIVERS_NET_WAN_DLCI_NETIF_POLL_DISABLE  	 0x00005390
#define DRIVERS_NET_WAN_SDLA_NETIF_POLL_DISABLE  	 0x00005391
#define DRIVERS_NET_WAN_SDLAMAIN_NETIF_POLL_DISABLE 	 0x00005392
#define DRIVERS_NET_WAN_SDLA_FT1_NETIF_POLL_DISABLE 	 0x00005393
#define DRIVERS_NET_WAN_SDLA_X25_NETIF_POLL_DISABLE 	 0x00005394
#define DRIVERS_NET_WAN_SDLA_FR_NETIF_POLL_DISABLE 	 0x00005395
#define DRIVERS_NET_WAN_SDLA_CHDLC_NETIF_POLL_DISABLE 	 0x00005396
#define DRIVERS_NET_WAN_SDLA_PPP_NETIF_POLL_DISABLE 	 0x00005397
#define DRIVERS_NET_WAN_WANPIPE_MULTPPP_NETIF_POLL_DISABLE 	 0x00005398
#define DRIVERS_NET_WAN_CYCX_DRV_DELAY_CYCX      	 0x00005399
#define DRIVERS_NET_WAN_CYCX_MAIN_NETIF_POLL_DISABLE 	 0x0000539a
#define DRIVERS_NET_WAN_CYCX_X25_NETIF_POLL_DISABLE 	 0x0000539b
#define DRIVERS_NET_WAN_LAPBETHER_NETIF_POLL_DISABLE 	 0x0000539c
#define DRIVERS_NET_WAN_SBNI_NETIF_POLL_DISABLE  	 0x0000539d
#define DRIVERS_NET_WAN_HDLC_GENERIC_NETIF_POLL_DISABLE 	 0x0000539e
#define DRIVERS_NET_WAN_HDLC_RAW_NETIF_POLL_DISABLE 	 0x0000539f
#define DRIVERS_NET_WAN_HDLC_RAW_ETH_NETIF_POLL_DISABLE 	 0x000053a0
#define DRIVERS_NET_WAN_HDLC_CISCO_NETIF_POLL_DISABLE 	 0x000053a1
#define DRIVERS_NET_WAN_HDLC_FR_NETIF_POLL_DISABLE 	 0x000053a2
#define DRIVERS_NET_WAN_HDLC_PPP_NETIF_POLL_DISABLE 	 0x000053a3
#define DRIVERS_NET_WAN_HDLC_X25_NETIF_POLL_DISABLE 	 0x000053a4
#define DRIVERS_NET_WAN_N2_NETIF_POLL_DISABLE    	 0x000053a5
#define DRIVERS_NET_WAN_C101_NETIF_POLL_DISABLE  	 0x000053a6
#define DRIVERS_NET_WIRELESS_ORINOCO_NETIF_POLL_DISABLE 	 0x000053a7
#define DRIVERS_NET_WIRELESS_ORINOCO_CS_NETIF_POLL_DISABLE 	 0x000053a8
#define DRIVERS_NET_WIRELESS_ORINOCO_PLX_NETIF_POLL_DISABLE 	 0x000053a9
#define DRIVERS_NET_WIRELESS_ORINOCO_PLX_ORINOCO_PLX_EXIT 	 0x000053aa
#define DRIVERS_NET_WIRELESS_ORINOCO_TMD_NETIF_POLL_DISABLE 	 0x000053ab
#define DRIVERS_NET_WIRELESS_ORINOCO_TMD_ORINOCO_TMD_EXIT 	 0x000053ac
#define DRIVERS_NET_WIRELESS_ORINOCO_PCI_NETIF_POLL_DISABLE 	 0x000053ad
#define DRIVERS_NET_SLHC_NETIF_POLL_DISABLE      	 0x000053ae
#define DRIVERS_NET_PLIP_NETIF_POLL_DISABLE      	 0x000053af
#define DRIVERS_NET_RRUNNER_NETIF_POLL_DISABLE   	 0x000053b0
#define DRIVERS_NET_SUNHME_NETIF_POLL_DISABLE    	 0x000053b1
#define DRIVERS_NET_SUNGEM_NETIF_POLL_DISABLE    	 0x000053b2
#define DRIVERS_NET_SUNGEM_GEM_SHUTDOWN          	 0x000053b3
#define DRIVERS_NET_DGRS_NETIF_POLL_DISABLE      	 0x000053b4
#define DRIVERS_NET_RCPCI45_NETIF_POLL_DISABLE   	 0x000053b5
#define DRIVERS_NET_RCLANMTL_NETIF_POLL_DISABLE  	 0x000053b6
#define DRIVERS_NET_3C59X_NETIF_POLL_DISABLE     	 0x000053b7
#define DRIVERS_NET_MII_NETIF_POLL_DISABLE       	 0x000053b8
#define DRIVERS_NET_TYPHOON_NETIF_POLL_DISABLE   	 0x000053b9
#define DRIVERS_NET_TYPHOON_TYPHOON_RESET        	 0x000053ba
#define DRIVERS_NET_NE2K_PCI_NETIF_POLL_DISABLE  	 0x000053bb
#define DRIVERS_NET_8390_NETIF_POLL_DISABLE      	 0x000053bc
#define DRIVERS_NET_PCNET32_NETIF_POLL_DISABLE   	 0x000053bd
#define DRIVERS_NET_EEPRO100_NETIF_POLL_DISABLE  	 0x000053be
#define DRIVERS_NET_TLAN_NETIF_POLL_DISABLE      	 0x000053bf
#define DRIVERS_NET_EPIC100_NETIF_POLL_DISABLE   	 0x000053c0
#define DRIVERS_NET_SIS900_NETIF_POLL_DISABLE    	 0x000053c1
#define DRIVERS_NET_SIS900_SIS900_MII_PROBE      	 0x000053c2
#define DRIVERS_NET_DMFE_NETIF_POLL_DISABLE      	 0x000053c3
#define DRIVERS_NET_YELLOWFIN_NETIF_POLL_DISABLE 	 0x000053c4
#define DRIVERS_NET_ACENIC_NETIF_POLL_DISABLE    	 0x000053c5
#define DRIVERS_NET_NATSEMI_NETIF_POLL_DISABLE   	 0x000053c6
#define DRIVERS_NET_NS83820_NETIF_POLL_DISABLE   	 0x000053c7
#define DRIVERS_NET_NS83820_NS83820_DO_RESET     	 0x000053c8
#define DRIVERS_NET_NS83820_NS83820_RUN_BIST     	 0x000053c9
#define DRIVERS_NET_NS83820_NS83820_INIT_ONE     	 0x000053ca
#define DRIVERS_NET_FEALNX_NETIF_POLL_DISABLE    	 0x000053cb
#define DRIVERS_NET_TG3_NETIF_POLL_DISABLE       	 0x000053cc
#define DRIVERS_NET_VIA_RHINE_NETIF_POLL_DISABLE 	 0x000053cd
#define DRIVERS_NET_AIRONET4500_CORE_NETIF_POLL_DISABLE 	 0x000053ce
#define DRIVERS_NET_AIRONET4500_CARD_NETIF_POLL_DISABLE 	 0x000053cf
#define DRIVERS_NET_AIRONET4500_PROC_NETIF_POLL_DISABLE 	 0x000053d0
#define DRIVERS_NET_WINBOND_840_NETIF_POLL_DISABLE 	 0x000053d1
#define DRIVERS_NET_SUNDANCE_NETIF_POLL_DISABLE  	 0x000053d2
#define DRIVERS_NET_HAMACHI_NETIF_POLL_DISABLE   	 0x000053d3
#define DRIVERS_NET_SPACE_NETIF_POLL_DISABLE     	 0x000053d4
#define DRIVERS_NET_SETUP_NETIF_POLL_DISABLE     	 0x000053d5
#define DRIVERS_NET_NET_INIT_NETIF_POLL_DISABLE  	 0x000053d6
#define DRIVERS_NET_LOOPBACK_NETIF_POLL_DISABLE  	 0x000053d7
#define DRIVERS_NET_ETHERTAP_NETIF_POLL_DISABLE  	 0x000053d8
#define DRIVERS_NET_SB1000_NETIF_POLL_DISABLE    	 0x000053d9
#define DRIVERS_NET_SB1000_NICEDELAY             	 0x000053da
#define DRIVERS_NET_SB1000_CARD_WAIT_FOR_BUSY_CLEAR 	 0x000053db
#define DRIVERS_NET_SB1000_CARD_WAIT_FOR_READY   	 0x000053dc
#define DRIVERS_NET_SHAPER_NETIF_POLL_DISABLE    	 0x000053dd
#define DRIVERS_NET_HP100_NETIF_POLL_DISABLE     	 0x000053de
#define DRIVERS_NET_HP100_HP100_DOWN_VG_LINK     	 0x000053df
#define DRIVERS_NET_HP100_HP100_LOGIN_TO_VG_HUB  	 0x000053e0
#define DRIVERS_NET_SMC9194_NETIF_POLL_DISABLE   	 0x000053e1
#define DRIVERS_NET_WD_NETIF_POLL_DISABLE        	 0x000053e2
#define DRIVERS_NET_3C503_NETIF_POLL_DISABLE     	 0x000053e3
#define DRIVERS_NET_NE_NETIF_POLL_DISABLE        	 0x000053e4
#define DRIVERS_NET_NE2_NETIF_POLL_DISABLE       	 0x000053e5
#define DRIVERS_NET_HP_NETIF_POLL_DISABLE        	 0x000053e6
#define DRIVERS_NET_HP_PLUS_NETIF_POLL_DISABLE   	 0x000053e7
#define DRIVERS_NET_SMC_ULTRA_NETIF_POLL_DISABLE 	 0x000053e8
#define DRIVERS_NET_SMC_MCA_NETIF_POLL_DISABLE   	 0x000053e9
#define DRIVERS_NET_SMC_ULTRA32_NETIF_POLL_DISABLE 	 0x000053ea
#define DRIVERS_NET_E2100_NETIF_POLL_DISABLE     	 0x000053eb
#define DRIVERS_NET_ES3210_NETIF_POLL_DISABLE    	 0x000053ec
#define DRIVERS_NET_LNE390_NETIF_POLL_DISABLE    	 0x000053ed
#define DRIVERS_NET_NE3210_NETIF_POLL_DISABLE    	 0x000053ee
#define DRIVERS_NET_PPP_GENERIC_NETIF_POLL_DISABLE 	 0x000053ef
#define DRIVERS_NET_PPP_GENERIC_PPP_READ         	 0x000053f0
#define DRIVERS_NET_PPP_ASYNC_NETIF_POLL_DISABLE 	 0x000053f1
#define DRIVERS_NET_PPP_SYNCTTY_NETIF_POLL_DISABLE 	 0x000053f2
#define DRIVERS_NET_PPPOX_NETIF_POLL_DISABLE     	 0x000053f3
#define DRIVERS_NET_PPPOE_NETIF_POLL_DISABLE     	 0x000053f4
#define DRIVERS_NET_SLIP_NETIF_POLL_DISABLE      	 0x000053f5
#define DRIVERS_NET_STRIP_NETIF_POLL_DISABLE     	 0x000053f6
#define DRIVERS_NET_DUMMY_NETIF_POLL_DISABLE     	 0x000053f7
#define DRIVERS_NET_DE600_NETIF_POLL_DISABLE     	 0x000053f8
#define DRIVERS_NET_DE620_NETIF_POLL_DISABLE     	 0x000053f9
#define DRIVERS_NET_LANCE_NETIF_POLL_DISABLE     	 0x000053fa
#define DRIVERS_NET_DEFXX_NETIF_POLL_DISABLE     	 0x000053fb
#define DRIVERS_NET_AT1700_NETIF_POLL_DISABLE    	 0x000053fc
#define DRIVERS_NET_3C501_NETIF_POLL_DISABLE     	 0x000053fd
#define DRIVERS_NET_3C507_NETIF_POLL_DISABLE     	 0x000053fe
#define DRIVERS_NET_3C523_NETIF_POLL_DISABLE     	 0x000053ff
#define DRIVERS_NET_SK_MCA_NETIF_POLL_DISABLE    	 0x00005400
#define DRIVERS_NET_IBMLANA_NETIF_POLL_DISABLE   	 0x00005401
#define DRIVERS_NET_3C527_NETIF_POLL_DISABLE     	 0x00005402
#define DRIVERS_NET_3C509_NETIF_POLL_DISABLE     	 0x00005403
#define DRIVERS_NET_3C515_NETIF_POLL_DISABLE     	 0x00005404
#define DRIVERS_NET_EEXPRESS_NETIF_POLL_DISABLE  	 0x00005405
#define DRIVERS_NET_EEPRO_NETIF_POLL_DISABLE     	 0x00005406
#define DRIVERS_NET_8139CP_NETIF_POLL_DISABLE    	 0x00005407
#define DRIVERS_NET_8139CP_CP_RESET_HW           	 0x00005408
#define DRIVERS_NET_8139TOO_NETIF_POLL_DISABLE   	 0x00005409
#define DRIVERS_NET_WAVELAN_NETIF_POLL_DISABLE   	 0x0000540a
#define DRIVERS_NET_ARLAN_NETIF_POLL_DISABLE     	 0x0000540b
#define DRIVERS_NET_ARLAN_PROC_NETIF_POLL_DISABLE 	 0x0000540c
#define DRIVERS_NET_DEPCA_NETIF_POLL_DISABLE     	 0x0000540d
#define DRIVERS_NET_EWRK3_NETIF_POLL_DISABLE     	 0x0000540e
#define DRIVERS_NET_EWRK3_EWRK3_ETHTOOL_IOCTL    	 0x0000540f
#define DRIVERS_NET_ATP_NETIF_POLL_DISABLE       	 0x00005410
#define DRIVERS_NET_DE4X5_NETIF_POLL_DISABLE     	 0x00005411
#define DRIVERS_NET_NI5010_NETIF_POLL_DISABLE    	 0x00005412
#define DRIVERS_NET_NI52_NETIF_POLL_DISABLE      	 0x00005413
#define DRIVERS_NET_NI65_NETIF_POLL_DISABLE      	 0x00005414
#define DRIVERS_NET_3C505_NETIF_POLL_DISABLE     	 0x00005415
#define DRIVERS_NET_AC3200_NETIF_POLL_DISABLE    	 0x00005416
#define DRIVERS_NET_82596_NETIF_POLL_DISABLE     	 0x00005417
#define DRIVERS_NET_LP486E_NETIF_POLL_DISABLE    	 0x00005418
#define DRIVERS_NET_ETH16I_NETIF_POLL_DISABLE    	 0x00005419
#define DRIVERS_NET_EQL_NETIF_POLL_DISABLE       	 0x0000541a
#define DRIVERS_NET_CS89X0_NETIF_POLL_DISABLE    	 0x0000541b
#define DRIVERS_NET_CS89X0_RESET_CHIP            	 0x0000541c
#define DRIVERS_NET_TUN_NETIF_POLL_DISABLE       	 0x0000541d
#define DRIVERS_NET_TUN_TUN_CHR_READV            	 0x0000541e
#define DRIVERS_NET_DL2K_NETIF_POLL_DISABLE      	 0x0000541f
#define DRIVERS_NET_R8169_NETIF_POLL_DISABLE     	 0x00005420
#define DRIVERS_NET_AMD8111E_NETIF_POLL_DISABLE  	 0x00005421
#define DRIVERS_NET_AUTO_IRQ_NETIF_POLL_DISABLE  	 0x00005422
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_NETIF_POLL_DISABLE 	 0x00005423
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_SBC_NETIF_POLL_DISABLE 	 0x00005424
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_WSS_NETIF_POLL_DISABLE 	 0x00005425
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_AFSK1200_NETIF_POLL_DISABLE 	 0x00005426
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_AFSK2400_7_NETIF_POLL_DISABLE 	 0x00005427
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_AFSK2400_8_NETIF_POLL_DISABLE 	 0x00005428
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_AFSK2666_NETIF_POLL_DISABLE 	 0x00005429
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_HAPN4800_NETIF_POLL_DISABLE 	 0x0000542a
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_PSK4800_NETIF_POLL_DISABLE 	 0x0000542b
#define DRIVERS_NET_HAMRADIO_SOUNDMODEM_SM_FSK9600_NETIF_POLL_DISABLE 	 0x0000542c
#define DRIVERS_NET_HAMRADIO_DMASCC_NETIF_POLL_DISABLE 	 0x0000542d
#define DRIVERS_NET_HAMRADIO_SCC_NETIF_POLL_DISABLE 	 0x0000542e
#define DRIVERS_NET_HAMRADIO_MKISS_NETIF_POLL_DISABLE 	 0x0000542f
#define DRIVERS_NET_HAMRADIO_6PACK_NETIF_POLL_DISABLE 	 0x00005430
#define DRIVERS_NET_HAMRADIO_YAM_NETIF_POLL_DISABLE 	 0x00005431
#define DRIVERS_NET_HAMRADIO_BPQETHER_NETIF_POLL_DISABLE 	 0x00005432
#define DRIVERS_NET_HAMRADIO_BAYCOM_SER_FDX_NETIF_POLL_DISABLE 	 0x00005433
#define DRIVERS_NET_HAMRADIO_HDLCDRV_NETIF_POLL_DISABLE 	 0x00005434
#define DRIVERS_NET_HAMRADIO_BAYCOM_SER_HDX_NETIF_POLL_DISABLE 	 0x00005435
#define DRIVERS_NET_HAMRADIO_BAYCOM_PAR_NETIF_POLL_DISABLE 	 0x00005436
#define DRIVERS_NET_HAMRADIO_BAYCOM_EPP_NETIF_POLL_DISABLE 	 0x00005437
#define DRIVERS_NET_HAMRADIO_BAYCOM_EPP_EPP_OPEN 	 0x00005438
#define DRIVERS_PARPORT_IEEE1284_PARPORT_WAIT_PERIPHERAL 	 0x00005401
#define DRIVERS_PARPORT_IEEE1284_OPS_PARPORT_IEEE1284_WRITE_COMPAT 	 0x00005402
#define DRIVERS_PARPORT_IEEE1284_OPS_PARPORT_IEEE1284_ECP_READ_DATA 	 0x00005403
#define DRIVERS_PARPORT_DAISY_PARPORT_DAISY_INIT 	 0x00005404
#define DRIVERS_PCI_PCI_PCI_SET_POWER_STATE      	 0x00005501
#define DRIVERS_PCI_PCI_PCI_POOL_ALLOC           	 0x00005502
#define DRIVERS_PCMCIA_DS_INIT_PCMCIA_DS         	 0x00005601
#define DRIVERS_PCMCIA_CS_CS_SLEEP               	 0x00005602
#define DRIVERS_PCMCIA_I82365_TEST_IRQ           	 0x00005603
#define DRIVERS_SCSI_AACRAID_COMMSUP_AAC_COMMAND_THREAD 	 0x00005701
#define DRIVERS_SCSI_AACRAID_RX_RX_SYNC_CMD      	 0x00005702
#define DRIVERS_SCSI_AACRAID_RX_AAC_RX_INIT      	 0x00005703
#define DRIVERS_SCSI_AACRAID_SA_SA_SYNC_CMD      	 0x00005704
#define DRIVERS_SCSI_AACRAID_SA_AAC_SA_INIT      	 0x00005705
#define DRIVERS_SCSI_SCSI_SCSI_ALLOCATE_DEVICE   	 0x00005706
#define DRIVERS_SCSI_SCSI_ERROR_SCSI_BLOCK_WHEN_PROCESSING_ERRORS 	 0x00005707
#define DRIVERS_SCSI_DPT_I2O_ADPT_I2O_POST_WAIT  	 0x00005708
#define DRIVERS_SCSI_DPT_I2O_ADPT_IOCTL          	 0x00005709
#define DRIVERS_SCSI_QLA1280_QLA1280_BUS_RESET   	 0x0000570a
#define DRIVERS_SCSI_3W_XXXX_TW_CHRDEV_IOCTL     	 0x0000570b
#define DRIVERS_SCSI_PPA_PPA_DETECT              	 0x0000570c
#define DRIVERS_SCSI_PPA_PPA_INIT                	 0x0000570d
#define DRIVERS_SCSI_PPA_PPA_COMMAND             	 0x0000570e
#define DRIVERS_SCSI_IMM_IMM_DETECT              	 0x0000570f
#define DRIVERS_SCSI_IMM_IMM_INIT                	 0x00005710
#define DRIVERS_SCSI_IMM_IMM_COMMAND             	 0x00005711
#define DRIVERS_SCSI_CPQFCTSINIT_CPQFCTS_DETECT  	 0x00005712
#define DRIVERS_SCSI_ST_TEST_READY               	 0x00005713
#define DRIVERS_SCSI_OSST_OSST_WAIT_READY        	 0x00005714
#define DRIVERS_SCSI_OSST_OSST_WAIT_FOR_MEDIUM   	 0x00005715
#define DRIVERS_SCSI_OSST_OSST_WAIT_FRAME        	 0x00005716
#define DRIVERS_SCSI_OSST_OSST_READ_BACK_BUFFER_AND_REWRITE 	 0x00005717
#define DRIVERS_SCSI_OSST_OSST_REPOSITION_AND_RETRY 	 0x00005718
#define DRIVERS_SCSI_SD_SD_INIT_ONEDISK          	 0x00005719
#define DRIVERS_SCSI_SG_SG_OPEN                  	 0x0000571a
#define DRIVERS_SCSI_SG_SG_READ                  	 0x0000571b
#define DRIVERS_SCSI_SG_SG_IOCTL                 	 0x0000571c
#define DRIVERS_SOUND_CS4281_CS4281M_DELAYUS     	 0x00005801
#define DRIVERS_SOUND_CS4281_CS4281M_DRAIN_ADC   	 0x00005802
#define DRIVERS_SOUND_CS4281_CS4281M_DRAIN_DAC   	 0x00005803
#define DRIVERS_SOUND_CS4281_CS4281M_CS4281_MIDI_RELEASE 	 0x00005804
#define DRIVERS_SOUND_EMU10K1_ECARD_EMU10K1_ECARD_INIT 	 0x00005805
#define DRIVERS_SOUND_MIDI_SYNTH_MIDI_SYNTH_LOAD_PATCH 	 0x00005806
#define DRIVERS_SOUND_CS4232_SLEEP               	 0x00005807
#define DRIVERS_SOUND_ALI5455_DRAIN_DAC          	 0x00005808
#define DRIVERS_SOUND_ALI5455_DRAIN_SPDIFOUT     	 0x00005809
#define DRIVERS_SOUND_ALI5455_ALI_READ           	 0x0000580a
#define DRIVERS_SOUND_ALI5455_ALI_WRITE          	 0x0000580b
#define DRIVERS_SOUND_ALI5455_ALI_OPEN           	 0x0000580c
#define DRIVERS_SOUND_ALI5455_ALI_OPEN_MIXDEV    	 0x0000580d
#define DRIVERS_SOUND_ALI5455_ALI_AC97_PROBE_AND_POWERUP 	 0x0000580e
#define DRIVERS_SOUND_ALI5455_ALI_AC97_RANDOM_INIT_STUFF 	 0x0000580f
#define DRIVERS_SOUND_SSCAPE_SLEEP               	 0x00005810
#define DRIVERS_SOUND_MAD16_WAIT_MS              	 0x00005811
#define DRIVERS_SOUND_MAUI_MAUI_WAIT             	 0x00005812
#define DRIVERS_SOUND_SGALAXY_SLEEP              	 0x00005813
#define DRIVERS_SOUND_AD1889_AD1889_WRITE        	 0x00005814
#define DRIVERS_SOUND_ACI_BUSY_WAIT              	 0x00005815
#define DRIVERS_SOUND_AWE_WAVE_AWE_WAIT          	 0x00005816
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DO_READ 	 0x00005817
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DO_WRITE 	 0x00005818
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DRAIN_PLAYBACK 	 0x00005819
#define DRIVERS_SOUND_YMFPCI_YMFPCI_CODEC_READY  	 0x0000581a
#define DRIVERS_SOUND_YMFPCI_YMF_WAIT_DAC        	 0x0000581b
#define DRIVERS_SOUND_YMFPCI_YMF_READ            	 0x0000581c
#define DRIVERS_SOUND_YMFPCI_YMF_WRITE           	 0x0000581d
#define DRIVERS_SOUND_I810_AUDIO_DRAIN_DAC       	 0x0000581e
#define DRIVERS_SOUND_I810_AUDIO_I810_READ       	 0x0000581f
#define DRIVERS_SOUND_I810_AUDIO_I810_WRITE      	 0x00005820
#define DRIVERS_SOUND_I810_AUDIO_I810_OPEN       	 0x00005821
#define DRIVERS_SOUND_I810_AUDIO_I810_OPEN_MIXDEV 	 0x00005822
#define DRIVERS_SOUND_I810_AUDIO_I810_AC97_PROBE_AND_POWERUP 	 0x00005823
#define DRIVERS_SOUND_I810_AUDIO_I810_AC97_POWER_UP_BUS 	 0x00005824
#define DRIVERS_SOUND_SONICVIBES_WAIT_MS         	 0x00005825
#define DRIVERS_SOUND_SONICVIBES_DRAIN_DAC       	 0x00005826
#define DRIVERS_SOUND_SONICVIBES_SV_READ         	 0x00005827
#define DRIVERS_SOUND_SONICVIBES_SV_WRITE        	 0x00005828
#define DRIVERS_SOUND_SONICVIBES_SV_OPEN         	 0x00005829
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_READ    	 0x0000582a
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_WRITE   	 0x0000582b
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_OPEN    	 0x0000582c
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_RELEASE 	 0x0000582d
#define DRIVERS_SOUND_SONICVIBES_SV_DMFM_OPEN    	 0x0000582e
#define DRIVERS_SOUND_CMPCI_WAIT_MS              	 0x0000582f
#define DRIVERS_SOUND_CMPCI_DRAIN_DAC            	 0x00005830
#define DRIVERS_SOUND_CMPCI_CM_READ              	 0x00005831
#define DRIVERS_SOUND_CMPCI_CM_WRITE             	 0x00005832
#define DRIVERS_SOUND_CMPCI_CM_OPEN              	 0x00005833
#define DRIVERS_SOUND_CMPCI_CM_MIDI_READ         	 0x00005834
#define DRIVERS_SOUND_CMPCI_CM_MIDI_WRITE        	 0x00005835
#define DRIVERS_SOUND_CMPCI_CM_MIDI_OPEN         	 0x00005836
#define DRIVERS_SOUND_CMPCI_CM_MIDI_RELEASE      	 0x00005837
#define DRIVERS_SOUND_CMPCI_CM_DMFM_OPEN         	 0x00005838
#define DRIVERS_SOUND_ES1370_WAIT_MS             	 0x00005839
#define DRIVERS_SOUND_ES1370_WRCODEC             	 0x0000583a
#define DRIVERS_SOUND_ES1370_DRAIN_DAC1          	 0x0000583b
#define DRIVERS_SOUND_ES1370_DRAIN_DAC2          	 0x0000583c
#define DRIVERS_SOUND_ES1370_ES1370_READ         	 0x0000583d
#define DRIVERS_SOUND_ES1370_ES1370_WRITE        	 0x0000583e
#define DRIVERS_SOUND_ES1370_ES1370_OPEN         	 0x0000583f
#define DRIVERS_SOUND_ES1370_ES1370_WRITE_DAC    	 0x00005840
#define DRIVERS_SOUND_ES1370_ES1370_OPEN_DAC     	 0x00005841
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_READ    	 0x00005842
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_WRITE   	 0x00005843
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_OPEN    	 0x00005844
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_RELEASE 	 0x00005845
#define DRIVERS_SOUND_ES1371_WAIT_MS             	 0x00005846
#define DRIVERS_SOUND_ES1371_DRAIN_DAC1          	 0x00005847
#define DRIVERS_SOUND_ES1371_DRAIN_DAC2          	 0x00005848
#define DRIVERS_SOUND_ES1371_ES1371_READ         	 0x00005849
#define DRIVERS_SOUND_ES1371_ES1371_WRITE        	 0x0000584a
#define DRIVERS_SOUND_ES1371_ES1371_OPEN         	 0x0000584b
#define DRIVERS_SOUND_ES1371_ES1371_WRITE_DAC    	 0x0000584c
#define DRIVERS_SOUND_ES1371_ES1371_OPEN_DAC     	 0x0000584d
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_READ    	 0x0000584e
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_WRITE   	 0x0000584f
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_OPEN    	 0x00005850
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_RELEASE 	 0x00005851
#define DRIVERS_SOUND_ES1371_ES1371_PROBE        	 0x00005852
#define DRIVERS_SOUND_ESSSOLO1_WAIT_MS           	 0x00005853
#define DRIVERS_SOUND_ESSSOLO1_DRAIN_DAC         	 0x00005854
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_READ        	 0x00005855
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_WRITE       	 0x00005856
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_OPEN        	 0x00005857
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_READ   	 0x00005858
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_WRITE  	 0x00005859
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_OPEN   	 0x0000585a
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_RELEASE 	 0x0000585b
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_DMFM_OPEN   	 0x0000585c
#define DRIVERS_SOUND_CS46XX_DRAIN_DAC           	 0x0000585d
#define DRIVERS_SOUND_CS46XX_CS_MIDI_RELEASE     	 0x0000585e
#define DRIVERS_SOUND_CS46XX_CS_READ             	 0x0000585f
#define DRIVERS_SOUND_CS46XX_CS_WRITE            	 0x00005860
#define DRIVERS_SOUND_CS46XX_CS_HARDWARE_INIT    	 0x00005861
#define DRIVERS_SOUND_MAESTRO_DRAIN_DAC          	 0x00005862
#define DRIVERS_SOUND_MAESTRO_CHECK_SUSPEND      	 0x00005863
#define DRIVERS_SOUND_MAESTRO3_DRAIN_DAC         	 0x00005864
#define DRIVERS_SOUND_MAESTRO3_M3_CODEC_RESET    	 0x00005865
#define DRIVERS_SOUND_MAESTRO3_CHECK_SUSPEND     	 0x00005866
#define DRIVERS_SOUND_FORTE_FORTE_CHANNEL_DRAIN  	 0x00005867
#define DRIVERS_SOUND_FORTE_FORTE_DSP_WRITE      	 0x00005868
#define DRIVERS_SOUND_FORTE_FORTE_DSP_READ       	 0x00005869
#define DRIVERS_SOUND_TRIDENT_WAIT_MS            	 0x0000586a
#define DRIVERS_SOUND_TRIDENT_DRAIN_DAC          	 0x0000586b
#define DRIVERS_SOUND_RME96XX_RME96XX_OPEN       	 0x0000586c
#define DRIVERS_SOUND_BTAUDIO_BTAUDIO_DSP_READ   	 0x0000586d
#define DRIVERS_SOUND_AC97_PLUGIN_WM97XX_WM97XX_READ 	 0x0000586e
#define DRIVERS_TELEPHONY_IXJ_IXJ_WINK           	 0x00005901
#define DRIVERS_TELEPHONY_IXJ_IXJ_REGISTER       	 0x00005902
#define DRIVERS_TELEPHONY_IXJ_IXJ_HOOKSTATE      	 0x00005903
#define DRIVERS_TELEPHONY_IXJ_IXJ_RING           	 0x00005904
#define DRIVERS_TELEPHONY_IXJ_IXJ_RELEASE        	 0x00005905
#define DRIVERS_TELEPHONY_IXJ_IXJ_WRITE_CIDCW    	 0x00005906
#define DRIVERS_TELEPHONY_IXJ_IXJ_IOCTL          	 0x00005907
#define DRIVERS_TELEPHONY_IXJ_IXJ_LINETEST       	 0x00005908
#define DRIVERS_TELEPHONY_IXJ_IXJ_SELFPROBE      	 0x00005909
#define DRIVERS_USB_SERIAL_USBSERIAL_WAIT_MS     	 0x00005a01
#define DRIVERS_USB_SERIAL_VISOR_WAIT_MS         	 0x00006101
#define DRIVERS_USB_SERIAL_IPAQ_WAIT_MS          	 0x00005a02
#define DRIVERS_USB_SERIAL_WHITEHEAT_WAIT_MS     	 0x00006102
#define DRIVERS_USB_SERIAL_FTDI_SIO_WAIT_MS      	 0x00005a03
#define DRIVERS_USB_SERIAL_KEYSPAN_PDA_WAIT_MS   	 0x00006103
#define DRIVERS_USB_SERIAL_KEYSPAN_WAIT_MS       	 0x00005a04
#define DRIVERS_USB_SERIAL_OMNINET_WAIT_MS       	 0x00006104
#define DRIVERS_USB_SERIAL_DIGI_ACCELEPORT_WAIT_MS 	 0x00005a05
#define DRIVERS_USB_SERIAL_DIGI_ACCELEPORT_COND_WAIT_INTERRUPTIBLE_TIMEOUT_IRQRESTORE 	 0x00005a06
#define DRIVERS_USB_SERIAL_BELKIN_SA_WAIT_MS     	 0x00006105
#define DRIVERS_USB_SERIAL_EMPEG_WAIT_MS         	 0x00005a07
#define DRIVERS_USB_SERIAL_MCT_U232_WAIT_MS      	 0x00006106
#define DRIVERS_USB_SERIAL_IO_EDGEPORT_WAIT_MS   	 0x00005a08
#define DRIVERS_USB_SERIAL_IO_TI_WAIT_MS         	 0x00006107
#define DRIVERS_USB_SERIAL_PL2303_WAIT_MS        	 0x00005a09
#define DRIVERS_USB_SERIAL_CYBERJACK_WAIT_MS     	 0x00006108
#define DRIVERS_USB_SERIAL_IR_USB_WAIT_MS        	 0x00005a0a
#define DRIVERS_USB_SERIAL_KL5KUSB105_WAIT_MS    	 0x00006109
#define DRIVERS_USB_STORAGE_SCSIGLUE_WAIT_MS     	 0x00005b01
#define DRIVERS_USB_STORAGE_PROTOCOL_WAIT_MS     	 0x0000610a
#define DRIVERS_USB_STORAGE_TRANSPORT_WAIT_MS    	 0x00005b02
#define DRIVERS_USB_STORAGE_TRANSPORT_USB_STOR_CB_RESET 	 0x00005b03
#define DRIVERS_USB_STORAGE_TRANSPORT_USB_STOR_BULK_RESET 	 0x00005b04
#define DRIVERS_USB_STORAGE_USB_WAIT_MS          	 0x0000610b
#define DRIVERS_USB_STORAGE_INITIALIZERS_WAIT_MS 	 0x00005b05
#define DRIVERS_USB_STORAGE_SHUTTLE_USBAT_WAIT_MS 	 0x0000610c
#define DRIVERS_USB_STORAGE_SDDR09_WAIT_MS       	 0x00005b06
#define DRIVERS_USB_STORAGE_SDDR55_WAIT_MS       	 0x0000610d
#define DRIVERS_USB_STORAGE_FREECOM_WAIT_MS      	 0x00005b07
#define DRIVERS_USB_STORAGE_DPCM_WAIT_MS         	 0x0000610e
#define DRIVERS_USB_STORAGE_ISD200_WAIT_MS       	 0x00005b08
#define DRIVERS_USB_STORAGE_DATAFAB_WAIT_MS      	 0x0000610f
#define DRIVERS_USB_STORAGE_JUMPSHOT_WAIT_MS     	 0x00005b09
#define DRIVERS_USB_USB_WAIT_MS                  	 0x00005c01
#define DRIVERS_USB_USB_USB_START_WAIT_URB       	 0x00005c02
#define DRIVERS_USB_USB_DEBUG_WAIT_MS            	 0x00005d01
#define DRIVERS_USB_HUB_WAIT_MS                  	 0x00005e01
#define DRIVERS_USB_HUB_USB_HUB_THREAD           	 0x00005e02
#define DRIVERS_USB_DEVIO_WAIT_MS                	 0x00005f01
#define DRIVERS_USB_DEVIO_PROC_REAPURB           	 0x00005f02
#define DRIVERS_USB_INODE_WAIT_MS                	 0x00006001
#define DRIVERS_USB_DRIVERS_WAIT_MS              	 0x00006110
#define DRIVERS_USB_DEVICES_WAIT_MS              	 0x00006111
#define DRIVERS_USB_HCD_WAIT_MS                  	 0x00006112
#define DRIVERS_USB_EHCI_HCD_WAIT_MS             	 0x00006113
#define DRIVERS_USB_UHCI_WAIT_MS                 	 0x00006114
#define DRIVERS_USB_UHCI_UHCI_UNLINK_URB         	 0x00006115
#define DRIVERS_USB_USB_OHCI_WAIT_MS             	 0x00006116
#define DRIVERS_USB_USB_OHCI_SOHCI_UNLINK_URB    	 0x00006117
#define DRIVERS_USB_USB_OHCI_SOHCI_FREE_DEV      	 0x00006118
#define DRIVERS_USB_HID_CORE_WAIT_MS             	 0x00006119
#define DRIVERS_USB_HIDDEV_WAIT_MS               	 0x0000611a
#define DRIVERS_USB_HIDDEV_HIDDEV_READ           	 0x0000611b
#define DRIVERS_USB_HID_INPUT_WAIT_MS            	 0x0000611c
#define DRIVERS_USB_AIPTEK_WAIT_MS               	 0x0000611d
#define DRIVERS_USB_WACOM_WAIT_MS                	 0x0000611e
#define DRIVERS_USB_KBTAB_WAIT_MS                	 0x0000611f
#define DRIVERS_USB_POWERMATE_WAIT_MS            	 0x00006120
#define DRIVERS_USB_SCANNER_WAIT_MS              	 0x00006121
#define DRIVERS_USB_ACM_WAIT_MS                  	 0x00006122
#define DRIVERS_USB_PRINTER_WAIT_MS              	 0x00006123
#define DRIVERS_USB_PRINTER_USBLP_WRITE          	 0x00006124
#define DRIVERS_USB_AUDIO_WAIT_MS                	 0x00006125
#define DRIVERS_USB_AUDIO_USBIN_STOP             	 0x00006126
#define DRIVERS_USB_AUDIO_USBOUT_STOP            	 0x00006127
#define DRIVERS_USB_AUDIO_DRAIN_OUT              	 0x00006128
#define DRIVERS_USB_AUDIO_USB_AUDIO_READ         	 0x00006129
#define DRIVERS_USB_AUDIO_USB_AUDIO_WRITE        	 0x0000612a
#define DRIVERS_USB_AUDIO_USB_AUDIO_OPEN         	 0x0000612b
#define DRIVERS_USB_EMI26_WAIT_MS                	 0x0000612c
#define DRIVERS_USB_USB_MIDI_WAIT_MS             	 0x0000612d
#define DRIVERS_USB_USB_MIDI_USB_MIDI_READ       	 0x0000612e
#define DRIVERS_USB_USB_MIDI_USB_MIDI_OPEN       	 0x0000612f
#define DRIVERS_USB_IBMCAM_WAIT_MS               	 0x00006130
#define DRIVERS_USB_USBVIDEO_WAIT_MS             	 0x00006131
#define DRIVERS_USB_ULTRACAM_WAIT_MS             	 0x00006132
#define DRIVERS_USB_KONICAWC_WAIT_MS             	 0x00006133
#define DRIVERS_USB_PWC_IF_WAIT_MS               	 0x00006134
#define DRIVERS_USB_PWC_IF_PWC_VIDEO_READ        	 0x00006135
#define DRIVERS_USB_PWC_IF_PWC_VIDEO_IOCTL       	 0x00006136
#define DRIVERS_USB_PWC_IF_USB_PWC_DISCONNECT    	 0x00006137
#define DRIVERS_USB_PWC_MISC_WAIT_MS             	 0x00006138
#define DRIVERS_USB_PWC_CTRL_WAIT_MS             	 0x00006139
#define DRIVERS_USB_PWC_UNCOMPRESS_WAIT_MS       	 0x0000613a
#define DRIVERS_USB_DC2XX_WAIT_MS                	 0x0000613b
#define DRIVERS_USB_MDC800_WAIT_MS               	 0x0000613c
#define DRIVERS_USB_MDC800_MDC800_USB_WAITFORIRQ 	 0x0000613d
#define DRIVERS_USB_MDC800_MDC800_DEVICE_READ    	 0x0000613e
#define DRIVERS_USB_MDC800_MDC800_DEVICE_WRITE   	 0x0000613f
#define DRIVERS_USB_USS720_WAIT_MS               	 0x00006140
#define DRIVERS_USB_USS720_CHANGE_MODE           	 0x00006141
#define DRIVERS_USB_DABUSB_WAIT_MS               	 0x00006142
#define DRIVERS_USB_DABUSB_DABUSB_OPEN           	 0x00006143
#define DRIVERS_USB_VICAM_WAIT_MS                	 0x00006144
#define DRIVERS_USB_OV511_WAIT_MS                	 0x00006145
#define DRIVERS_USB_OV511_INIT_OV_SENSOR         	 0x00006146
#define DRIVERS_USB_OV511_OV51X_V4L1_IOCTL_INTERNAL 	 0x00006147
#define DRIVERS_USB_OV511_OV51X_V4L1_READ        	 0x00006148
#define DRIVERS_USB_OV511_OV7XX0_CONFIGURE       	 0x00006149
#define DRIVERS_USB_W9968CF_WAIT_MS              	 0x0000614a
#define DRIVERS_USB_W9968CF_W9968CF_OPEN         	 0x0000614b
#define DRIVERS_USB_W9968CF_W9968CF_READ         	 0x0000614c
#define DRIVERS_USB_W9968CF_W9968CF_DO_IOCTL     	 0x0000614d
#define DRIVERS_USB_SE401_WAIT_MS                	 0x0000614e
#define DRIVERS_USB_SE401_SE401_NEWFRAME         	 0x0000614f
#define DRIVERS_USB_STV680_WAIT_MS               	 0x00006150
#define DRIVERS_USB_STV680_STV680_NEWFRAME       	 0x00006151
#define DRIVERS_USB_PEGASUS_NETIF_POLL_DISABLE   	 0x00006152
#define DRIVERS_USB_PEGASUS_WAIT_MS              	 0x00006153
#define DRIVERS_USB_PEGASUS_GET_REGISTERS        	 0x00006154
#define DRIVERS_USB_PEGASUS_SET_REGISTERS        	 0x00006155
#define DRIVERS_USB_PEGASUS_SET_REGISTER         	 0x00006156
#define DRIVERS_USB_RTL8150_NETIF_POLL_DISABLE   	 0x00006157
#define DRIVERS_USB_RTL8150_WAIT_MS              	 0x00006158
#define DRIVERS_USB_CATC_NETIF_POLL_DISABLE      	 0x00006159
#define DRIVERS_USB_CATC_WAIT_MS                 	 0x0000615a
#define DRIVERS_USB_KAWETH_NETIF_POLL_DISABLE    	 0x0000615b
#define DRIVERS_USB_KAWETH_WAIT_MS               	 0x0000615c
#define DRIVERS_USB_KAWETH_KAWETH_DISCONNECT     	 0x0000615d
#define DRIVERS_USB_KAWETH_USB_START_WAIT_URB    	 0x0000615e
#define DRIVERS_USB_AX8817X_WAIT_MS              	 0x0000615f
#define DRIVERS_USB_AX8817X_NETIF_POLL_DISABLE   	 0x00006160
#define DRIVERS_USB_AX8817X_AX_CONTROL_MSG       	 0x00006161
#define DRIVERS_USB_CDCETHER_NETIF_POLL_DISABLE  	 0x00006162
#define DRIVERS_USB_CDCETHER_WAIT_MS             	 0x00006163
#define DRIVERS_USB_RIO500_WAIT_MS               	 0x00006164
#define DRIVERS_USB_TIGLUSB_WAIT_MS              	 0x00006165
#define DRIVERS_USB_TIGLUSB_TIGLUSB_OPEN         	 0x00006166
#define DRIVERS_USB_DSBR100_WAIT_MS              	 0x00006167
#define DRIVERS_USB_MICROTEK_WAIT_MS             	 0x00006168
#define DRIVERS_USB_HPUSBSCSI_WAIT_MS            	 0x00006169
#define DRIVERS_USB_USBNET_NETIF_POLL_DISABLE    	 0x0000616a
#define DRIVERS_USB_USBNET_WAIT_MS               	 0x0000616b
#define DRIVERS_USB_USBNET_USBNET_STOP           	 0x0000616c
#define DRIVERS_USB_AUERBUF_WAIT_MS              	 0x0000616d
#define DRIVERS_USB_AUERCHAIN_WAIT_MS            	 0x0000616e
#define DRIVERS_USB_AUERCHAIN_AUERCHAIN_START_WAIT_URB 	 0x0000616f
#define DRIVERS_USB_AUERCHAR_WAIT_MS             	 0x00006170
#define DRIVERS_USB_AUERCHAR_AUERCHAR_READ       	 0x00006171
#define DRIVERS_USB_AUERCHAR_AUERCHAR_WRITE      	 0x00006172
#define DRIVERS_USB_AUERMAIN_WAIT_MS             	 0x00006173
#define DRIVERS_USB_AUERISDN_NETIF_POLL_DISABLE  	 0x00006174
#define DRIVERS_USB_AUERISDN_WAIT_MS             	 0x00006175
#define DRIVERS_USB_AUERISDN_B_NETIF_POLL_DISABLE 	 0x00006176
#define DRIVERS_USB_AUERISDN_B_WAIT_MS           	 0x00006177
#define DRIVERS_USB_BRLVGER_WAIT_MS              	 0x00006178
#define DRIVERS_USB_BRLVGER_BRLVGER_OPEN         	 0x00006179
#define DRIVERS_USB_BRLVGER_BRLVGER_READ         	 0x0000617a
#define DRIVERS_USB_USBLCD_WAIT_MS               	 0x0000617b
#define DRIVERS_USB_SPEEDTCH_NETIF_POLL_DISABLE  	 0x0000617c
#define DRIVERS_USB_SPEEDTCH_WAIT_MS             	 0x0000617d
#define DRIVERS_USB_SPEEDTCH_UDSL_USB_DISCONNECT 	 0x0000617e
#define DRIVERS_VIDEO_MATROX_MATROXFB_BASE_MATROXFB_WAIT_FOR_SYNC 	 0x00006201
#define MM_FILEMAP_TRUNCATE_LIST_PAGES           	 0x00006301
#define MM_FILEMAP_INVALIDATE_LIST_PAGES2        	 0x00006302
#define MM_FILEMAP____WAIT_ON_PAGE               	 0x00006303
#define MM_FILEMAP___LOCK_PAGE                   	 0x00006304
#define MM_VMSCAN_SWAP_OUT                       	 0x00006305
#define MM_VMSCAN_SHRINK_CACHE                   	 0x00006306
#define MM_VMSCAN_KSWAPD_BALANCE_PGDAT           	 0x00006307
#define MM_VMSCAN_KSWAPD                         	 0x00006308
#define MM_SWAPFILE_TRY_TO_UNUSE                 	 0x00006309
#define FS_CODA_PSDEV_CODA_PSDEV_READ            	 0x00006401
#define FS_CODA_UPCALL_CODA_WAITFOR_UPCALL       	 0x00006402
#define FS_DEVFS_BASE_WAIT_FOR_DEVFSD_FINISHED   	 0x00006501
#define FS_DEVFS_BASE_DEVFS_D_REVALIDATE_WAIT    	 0x00006502
#define FS_DEVFS_BASE_DEVFSD_READ                	 0x00006503
#define FS_EXT3_IOCTL_EXT3_IOCTL                 	 0x00006601
#define FS_HFS_BALLOC_HFS_RELINQUISH             	 0x00006701
#define FS_HFS_BDELETE_HFS_RELINQUISH            	 0x00006702
#define FS_HFS_BFIND_HFS_RELINQUISH              	 0x00006703
#define FS_HFS_BINS_DEL_HFS_RELINQUISH           	 0x00006704
#define FS_HFS_BINSERT_HFS_RELINQUISH            	 0x00006705
#define FS_HFS_BITMAP_HFS_RELINQUISH             	 0x00006706
#define FS_HFS_BITOPS_HFS_RELINQUISH             	 0x00006707
#define FS_HFS_BNODE_HFS_RELINQUISH              	 0x00006708
#define FS_HFS_BREC_HFS_RELINQUISH               	 0x00006709
#define FS_HFS_BTREE_HFS_RELINQUISH              	 0x0000670a
#define FS_HFS_CATALOG_HFS_RELINQUISH            	 0x0000670b
#define FS_HFS_DIR_HFS_RELINQUISH                	 0x0000670c
#define FS_HFS_DIR_CAP_HFS_RELINQUISH            	 0x0000670d
#define FS_HFS_DIR_DBL_HFS_RELINQUISH            	 0x0000670e
#define FS_HFS_DIR_NAT_HFS_RELINQUISH            	 0x0000670f
#define FS_HFS_EXTENT_HFS_RELINQUISH             	 0x00006710
#define FS_HFS_FILE_HFS_RELINQUISH               	 0x00006711
#define FS_HFS_FILE_CAP_HFS_RELINQUISH           	 0x00006712
#define FS_HFS_FILE_HDR_HFS_RELINQUISH           	 0x00006713
#define FS_HFS_INODE_HFS_RELINQUISH              	 0x00006714
#define FS_HFS_MDB_HFS_RELINQUISH                	 0x00006715
#define FS_HFS_PART_TBL_HFS_RELINQUISH           	 0x00006716
#define FS_HFS_STRING_HFS_RELINQUISH             	 0x00006717
#define FS_HFS_SUPER_HFS_RELINQUISH              	 0x00006718
#define FS_HFS_SYSDEP_HFS_RELINQUISH             	 0x00006719
#define FS_HFS_TRANS_HFS_RELINQUISH              	 0x0000671a
#define FS_HFSPLUS_BNODE___HFSPLUS_CREATE_BNODE  	 0x00006801
#define FS_HFSPLUS_BNODE_HFSPLUS_FIND_BNODE      	 0x00006802
#define FS_HFSPLUS_BNODE_HFSPLUS_LOCK_BNODE      	 0x00006803
#define FS_INTERMEZZO_PRESTO_PRESTO_GET_PERMIT   	 0x00006901
#define FS_INTERMEZZO_PRESTO_IZO_REVOKE_PERMIT   	 0x00006902
#define FS_INTERMEZZO_PSDEV_LENTO_WAITFOR_UPCALL 	 0x00006903
#define FS_JBD_TRANSACTION_DO_GET_WRITE_ACCESS   	 0x00006a01
#define FS_JBD_COMMIT_JOURNAL_COMMIT_TRANSACTION 	 0x00006a02
#define FS_JFFS_INTREP_FLASH_ERASE_REGION        	 0x00006b01
#define FS_JFFS_INTREP_JFFS_GARBAGE_COLLECT_THREAD 	 0x00006b02
#define FS_JFFS2_NODEMGMT_JFFS2_RESERVE_SPACE    	 0x00006c01
#define FS_JFFS2_NODEMGMT_JFFS2_DO_RESERVE_SPACE 	 0x00006c02
#define FS_JFFS2_ERASE_JFFS2_ERASE_PENDING_BLOCKS 	 0x00006c03
#define FS_JFFS2_BACKGROUND_JFFS2_GARBAGE_COLLECT_THREAD 	 0x00006c04
#define FS_LOCKD_CLNTPROC_NLMCLNT_ALLOC_CALL     	 0x00006d01
#define FS_NCPFS_SOCK_NETIF_POLL_DISABLE         	 0x00006e01
#define FS_NCPFS_SOCK_DO_NCP_RPC_CALL            	 0x00006e02
#define FS_NCPFS_SOCK_DO_TCP_RCV                 	 0x00006e03
#define FS_NCPFS_SYMLINK_NCP_SYMLINK_READPAGE    	 0x00006e04
#define FS_NFS_DIR_FIND_DIRENT                   	 0x00006f01
#define FS_NFS_DIR_READDIR_SEARCH_PAGECACHE      	 0x00006f02
#define FS_NFS_DIR_NFS_DO_FILLDIR                	 0x00006f03
#define FS_NFS_INODE_NFS_WAIT_ON_INODE           	 0x00006f04
#define FS_NFS_PAGELIST_NFS_WAIT_ON_REQUEST      	 0x00006f05
#define FS_NFS_NFS3PROC_NFS3_RPC_WRAPPER         	 0x00006f06
#define FS_NFSD_VFS_NFSD_WRITE                   	 0x00007001
#define FS_NTFS_DIR_NTFS_ALLOCATE_INDEX_BLOCK    	 0x00007101
#define FS_PARTITIONS_CHECK_NETIF_POLL_DISABLE   	 0x00007201
#define FS_REISERFS_INODE_REISERFS_GET_BLOCK     	 0x00007301
#define FS_REISERFS_FIX_NODE_GET_MEM_FOR_VIRTUAL_NODE 	 0x00007302
#define FS_REISERFS_JOURNAL_REISERFS_WAIT_ON_WRITE_BLOCK 	 0x00007303
#define FS_SMBFS_PROC_SMB_PROC_READDIR_LONG      	 0x00007401
#define FS_SMBFS_SOCK_NETIF_POLL_DISABLE         	 0x00007402
#define FS_SMBFS_SOCK_SMB_RECEIVE_POLL           	 0x00007403
#define FS_BUFFER___WAIT_ON_BUFFER               	 0x00007501
#define FS_BUFFER_KUPDATE                        	 0x00007502
#define FS_PIPE_PIPE_WAIT                        	 0x00007601
#define FS_NAMEI_DO_FOLLOW_LINK                  	 0x00007701
#define FS_SELECT_DO_SELECT                      	 0x00007801
#define FS_SELECT_DO_POLL                        	 0x00007802
#define FS_LOCKS_INTERRUPTIBLE_SLEEP_ON_LOCKED   	 0x00007901
#define FS_INODE___WAIT_ON_INODE                 	 0x00007a01
#define FS_INODE___WAIT_ON_FREEING_INODE         	 0x00007a02
#define FS_IOBUF_KIOBUF_WAIT_FOR_IO              	 0x00007b01
#define FS_DQUOT___WAIT_ON_DQUOT                 	 0x00007c01
#define FS_DQUOT___WAIT_DQUOT_UNUSED             	 0x00007c02
#define FS_DQUOT___WAIT_DUP_DROP                 	 0x00007c03
#define FS_DQUOT_DQGET                           	 0x00007c04
#define NET_802_P8023_NETIF_POLL_DISABLE         	 0x00007d01
#define NET_802_LLC_SENDPDU_NETIF_POLL_DISABLE   	 0x00007d02
#define NET_802_LLC_UTILITY_NETIF_POLL_DISABLE   	 0x00007d03
#define NET_802_CL2LLC_NETIF_POLL_DISABLE        	 0x00007d04
#define NET_802_LLC_MACINIT_NETIF_POLL_DISABLE   	 0x00007d05
#define NET_802_TR_NETIF_POLL_DISABLE            	 0x00007d06
#define NET_802_FC_NETIF_POLL_DISABLE            	 0x00007d07
#define NET_802_FDDI_NETIF_POLL_DISABLE          	 0x00007d08
#define NET_802_HIPPI_NETIF_POLL_DISABLE         	 0x00007d09
#define NET_802_P8022_NETIF_POLL_DISABLE         	 0x00007d0a
#define NET_802_PSNAP_NETIF_POLL_DISABLE         	 0x00007d0b
#define NET_8021Q_VLAN_NETIF_POLL_DISABLE        	 0x00007e01
#define NET_8021Q_VLANPROC_NETIF_POLL_DISABLE    	 0x00007e02
#define NET_8021Q_VLAN_DEV_NETIF_POLL_DISABLE    	 0x00007e03
#define NET_APPLETALK_AARP_NETIF_POLL_DISABLE    	 0x00007f01
#define NET_APPLETALK_AARP_AARP_PROBE_NETWORK    	 0x00007f02
#define NET_APPLETALK_AARP_AARP_PROXY_PROBE_NETWORK 	 0x00007f03
#define NET_APPLETALK_DDP_NETIF_POLL_DISABLE     	 0x00007f04
#define NET_ATM_ADDR_NETIF_POLL_DISABLE          	 0x00008001
#define NET_ATM_PVC_NETIF_POLL_DISABLE           	 0x00008002
#define NET_ATM_SIGNALING_NETIF_POLL_DISABLE     	 0x00008003
#define NET_ATM_SIGNALING_MODIFY_QOS             	 0x00008004
#define NET_ATM_SIGNALING_SIGD_ENQ2              	 0x00008005
#define NET_ATM_SVC_NETIF_POLL_DISABLE           	 0x00008006
#define NET_ATM_SVC_SVC_DISCONNECT               	 0x00008007
#define NET_ATM_SVC_SVC_BIND                     	 0x00008008
#define NET_ATM_SVC_SVC_CONNECT                  	 0x00008009
#define NET_ATM_SVC_SVC_LISTEN                   	 0x0000800a
#define NET_ATM_SVC_SVC_ACCEPT                   	 0x0000800b
#define NET_ATM_SVC_SVC_CHANGE_QOS               	 0x0000800c
#define NET_ATM_COMMON_NETIF_POLL_DISABLE        	 0x0000800d
#define NET_ATM_COMMON_ALLOC_TX                  	 0x0000800e
#define NET_ATM_COMMON_VCC_SENDMSG               	 0x0000800f
#define NET_ATM_ATM_MISC_NETIF_POLL_DISABLE      	 0x00008010
#define NET_ATM_RAW_NETIF_POLL_DISABLE           	 0x00008011
#define NET_ATM_RESOURCES_NETIF_POLL_DISABLE     	 0x00008012
#define NET_ATM_RESOURCES_ATM_DEV_DEREGISTER     	 0x00008013
#define NET_ATM_CLIP_NETIF_POLL_DISABLE          	 0x00008014
#define NET_ATM_BR2684_NETIF_POLL_DISABLE        	 0x00008015
#define NET_ATM_IPCOMMON_NETIF_POLL_DISABLE      	 0x00008016
#define NET_ATM_PROC_NETIF_POLL_DISABLE          	 0x00008017
#define NET_ATM_LEC_NETIF_POLL_DISABLE           	 0x00008018
#define NET_ATM_MPC_NETIF_POLL_DISABLE           	 0x00008019
#define NET_ATM_MPOA_CACHES_NETIF_POLL_DISABLE   	 0x0000801a
#define NET_ATM_MPOA_PROC_NETIF_POLL_DISABLE     	 0x0000801b
#define NET_ATM_PPPOATM_NETIF_POLL_DISABLE       	 0x0000801c
#define NET_AX25_AX25_ADDR_NETIF_POLL_DISABLE    	 0x00008101
#define NET_AX25_AX25_DEV_NETIF_POLL_DISABLE     	 0x00008102
#define NET_AX25_AX25_IFACE_NETIF_POLL_DISABLE   	 0x00008103
#define NET_AX25_AX25_IN_NETIF_POLL_DISABLE      	 0x00008104
#define NET_AX25_AX25_IP_NETIF_POLL_DISABLE      	 0x00008105
#define NET_AX25_AX25_OUT_NETIF_POLL_DISABLE     	 0x00008106
#define NET_AX25_AX25_ROUTE_NETIF_POLL_DISABLE   	 0x00008107
#define NET_AX25_AX25_STD_IN_NETIF_POLL_DISABLE  	 0x00008108
#define NET_AX25_AX25_STD_SUBR_NETIF_POLL_DISABLE 	 0x00008109
#define NET_AX25_AX25_STD_TIMER_NETIF_POLL_DISABLE 	 0x0000810a
#define NET_AX25_AX25_SUBR_NETIF_POLL_DISABLE    	 0x0000810b
#define NET_AX25_AX25_TIMER_NETIF_POLL_DISABLE   	 0x0000810c
#define NET_AX25_AX25_UID_NETIF_POLL_DISABLE     	 0x0000810d
#define NET_AX25_AF_AX25_NETIF_POLL_DISABLE      	 0x0000810e
#define NET_AX25_AX25_DS_IN_NETIF_POLL_DISABLE   	 0x0000810f
#define NET_AX25_AX25_DS_SUBR_NETIF_POLL_DISABLE 	 0x00008110
#define NET_AX25_AX25_DS_TIMER_NETIF_POLL_DISABLE 	 0x00008111
#define NET_AX25_SYSCTL_NET_AX25_NETIF_POLL_DISABLE 	 0x00008112
#define NET_BLUETOOTH_BNEP_CORE_NETIF_POLL_DISABLE 	 0x00008201
#define NET_BLUETOOTH_BNEP_CORE_BNEP_SESSION     	 0x00008202
#define NET_BLUETOOTH_BNEP_SOCK_NETIF_POLL_DISABLE 	 0x00008203
#define NET_BLUETOOTH_BNEP_NETDEV_NETIF_POLL_DISABLE 	 0x00008204
#define NET_BLUETOOTH_CMTP_CORE_NETIF_POLL_DISABLE 	 0x00008205
#define NET_BLUETOOTH_CMTP_CORE_CMTP_SESSION     	 0x00008206
#define NET_BLUETOOTH_CMTP_SOCK_NETIF_POLL_DISABLE 	 0x00008207
#define NET_BLUETOOTH_CMTP_CAPI_NETIF_POLL_DISABLE 	 0x00008208
#define NET_BLUETOOTH_CMTP_CAPI_CMTP_REGISTER_APPL 	 0x00008209
#define NET_BLUETOOTH_CMTP_CAPI_CMTP_RELEASE_APPL 	 0x0000820a
#define NET_BLUETOOTH_CMTP_CAPI_CMTP_ATTACH_DEVICE 	 0x0000820b
#define NET_BLUETOOTH_RFCOMM_CORE_NETIF_POLL_DISABLE 	 0x0000820c
#define NET_BLUETOOTH_RFCOMM_CORE_RFCOMM_WORKER  	 0x0000820d
#define NET_BLUETOOTH_RFCOMM_CORE_RFCOMM_CLEANUP 	 0x0000820e
#define NET_BLUETOOTH_RFCOMM_SOCK_NETIF_POLL_DISABLE 	 0x0000820f
#define NET_BLUETOOTH_RFCOMM_SOCK_RFCOMM_SOCK_ACCEPT 	 0x00008210
#define NET_BLUETOOTH_RFCOMM_SOCK_RFCOMM_SOCK_DATA_WAIT 	 0x00008211
#define NET_BLUETOOTH_RFCOMM_TTY_NETIF_POLL_DISABLE 	 0x00008212
#define NET_BLUETOOTH_RFCOMM_TTY_RFCOMM_TTY_OPEN 	 0x00008213
#define NET_BLUETOOTH_AF_BLUETOOTH_NETIF_POLL_DISABLE 	 0x00008214
#define NET_BLUETOOTH_AF_BLUETOOTH_BLUEZ_SOCK_WAIT_STATE 	 0x00008215
#define NET_BLUETOOTH_HCI_CORE_NETIF_POLL_DISABLE 	 0x00008216
#define NET_BLUETOOTH_HCI_CORE___HCI_REQUEST     	 0x00008217
#define NET_BLUETOOTH_HCI_CONN_NETIF_POLL_DISABLE 	 0x00008218
#define NET_BLUETOOTH_HCI_EVENT_NETIF_POLL_DISABLE 	 0x00008219
#define NET_BLUETOOTH_HCI_SOCK_NETIF_POLL_DISABLE 	 0x0000821a
#define NET_BLUETOOTH_LIB_NETIF_POLL_DISABLE     	 0x0000821b
#define NET_BLUETOOTH_SYMS_NETIF_POLL_DISABLE    	 0x0000821c
#define NET_BLUETOOTH_L2CAP_NETIF_POLL_DISABLE   	 0x0000821d
#define NET_BLUETOOTH_L2CAP_L2CAP_SOCK_ACCEPT    	 0x0000821e
#define NET_BLUETOOTH_SCO_NETIF_POLL_DISABLE     	 0x0000821f
#define NET_BLUETOOTH_SCO_SCO_SOCK_ACCEPT        	 0x00008220
#define NET_BRIDGE_BR_NETIF_POLL_DISABLE         	 0x00008301
#define NET_BRIDGE_BR_DEVICE_NETIF_POLL_DISABLE  	 0x00008302
#define NET_BRIDGE_BR_FDB_NETIF_POLL_DISABLE     	 0x00008303
#define NET_BRIDGE_BR_FORWARD_NETIF_POLL_DISABLE 	 0x00008304
#define NET_BRIDGE_BR_IF_NETIF_POLL_DISABLE      	 0x00008305
#define NET_BRIDGE_BR_INPUT_NETIF_POLL_DISABLE   	 0x00008306
#define NET_BRIDGE_BR_IOCTL_NETIF_POLL_DISABLE   	 0x00008307
#define NET_BRIDGE_BR_NOTIFY_NETIF_POLL_DISABLE  	 0x00008308
#define NET_BRIDGE_BR_STP_NETIF_POLL_DISABLE     	 0x00008309
#define NET_BRIDGE_BR_STP_BPDU_NETIF_POLL_DISABLE 	 0x0000830a
#define NET_BRIDGE_BR_STP_IF_NETIF_POLL_DISABLE  	 0x0000830b
#define NET_BRIDGE_BR_STP_TIMER_NETIF_POLL_DISABLE 	 0x0000830c
#define NET_CORE_SOCK_NETIF_POLL_DISABLE         	 0x00008401
#define NET_CORE_SOCK_SOCK_WAIT_FOR_WMEM         	 0x00008402
#define NET_CORE_SOCK___LOCK_SOCK                	 0x00008403
#define NET_CORE_SKBUFF_NETIF_POLL_DISABLE       	 0x00008404
#define NET_CORE_IOVEC_NETIF_POLL_DISABLE        	 0x00008405
#define NET_CORE_DATAGRAM_NETIF_POLL_DISABLE     	 0x00008406
#define NET_CORE_DATAGRAM_WAIT_FOR_PACKET        	 0x00008407
#define NET_CORE_SCM_NETIF_POLL_DISABLE          	 0x00008408
#define NET_CORE_FILTER_NETIF_POLL_DISABLE       	 0x00008409
#define NET_CORE_DEV_NETIF_POLL_DISABLE          	 0x0000840a
#define NET_CORE_DEV_DEV_CLOSE                   	 0x0000840b
#define NET_CORE_DEV_UNREGISTER_NETDEVICE        	 0x0000840c
#define NET_CORE_ETHTOOL_NETIF_POLL_DISABLE      	 0x0000840d
#define NET_CORE_DEV_MCAST_NETIF_POLL_DISABLE    	 0x0000840e
#define NET_CORE_DST_NETIF_POLL_DISABLE          	 0x0000840f
#define NET_CORE_NEIGHBOUR_NETIF_POLL_DISABLE    	 0x00008410
#define NET_CORE_RTNETLINK_NETIF_POLL_DISABLE    	 0x00008411
#define NET_CORE_NETFILTER_NETIF_POLL_DISABLE    	 0x00008412
#define NET_CORE_NETFILTER_NF_UNREGISTER_SOCKOPT 	 0x00008413
#define NET_CORE_DV_NETIF_POLL_DISABLE           	 0x00008414
#define NET_CORE_PKTGEN_NETIF_POLL_DISABLE       	 0x00008415
#define NET_CORE_PKTGEN_INJECT                   	 0x00008416
#define NET_CORE_WIRELESS_NETIF_POLL_DISABLE     	 0x00008417
#define NET_DECNET_AF_DECNET_NETIF_POLL_DISABLE  	 0x00008501
#define NET_DECNET_AF_DECNET_DN_CONNECT          	 0x00008502
#define NET_DECNET_AF_DECNET_DN_WAIT_ACCEPT      	 0x00008503
#define NET_DECNET_AF_DECNET_DN_ACCEPT           	 0x00008504
#define NET_DECNET_AF_DECNET_DN_WAIT_RUN         	 0x00008505
#define NET_DECNET_AF_DECNET_DN_RECVMSG          	 0x00008506
#define NET_DECNET_AF_DECNET_DN_SENDMSG          	 0x00008507
#define NET_DECNET_DN_NSP_IN_NETIF_POLL_DISABLE  	 0x00008508
#define NET_DECNET_DN_NSP_OUT_NETIF_POLL_DISABLE 	 0x00008509
#define NET_DECNET_DN_NSP_OUT_DN_ALLOC_SEND_SKB  	 0x0000850a
#define NET_DECNET_DN_ROUTE_NETIF_POLL_DISABLE   	 0x0000850b
#define NET_DECNET_DN_DEV_NETIF_POLL_DISABLE     	 0x0000850c
#define NET_DECNET_DN_NEIGH_NETIF_POLL_DISABLE   	 0x0000850d
#define NET_DECNET_DN_TIMER_NETIF_POLL_DISABLE   	 0x0000850e
#define NET_DECNET_DN_FIB_NETIF_POLL_DISABLE     	 0x0000850f
#define NET_DECNET_DN_RULES_NETIF_POLL_DISABLE   	 0x00008510
#define NET_DECNET_DN_TABLE_NETIF_POLL_DISABLE   	 0x00008511
#define NET_DECNET_SYSCTL_NET_DECNET_NETIF_POLL_DISABLE 	 0x00008512
#define NET_ECONET_AF_ECONET_NETIF_POLL_DISABLE  	 0x00008601
#define NET_ETHERNET_ETH_NETIF_POLL_DISABLE      	 0x00008701
#define NET_ETHERNET_PE2_NETIF_POLL_DISABLE      	 0x00008702
#define NET_IPV4_ROUTE_NETIF_POLL_DISABLE        	 0x00008801
#define NET_IPV4_PROC_NETIF_POLL_DISABLE         	 0x00008802
#define NET_IPV4_PROTOCOL_NETIF_POLL_DISABLE     	 0x00008803
#define NET_IPV4_IP_INPUT_NETIF_POLL_DISABLE     	 0x00008804
#define NET_IPV4_IP_FRAGMENT_NETIF_POLL_DISABLE  	 0x00008805
#define NET_IPV4_IP_FORWARD_NETIF_POLL_DISABLE   	 0x00008806
#define NET_IPV4_IP_OPTIONS_NETIF_POLL_DISABLE   	 0x00008807
#define NET_IPV4_IP_OUTPUT_NETIF_POLL_DISABLE    	 0x00008808
#define NET_IPV4_IP_SOCKGLUE_NETIF_POLL_DISABLE  	 0x00008809
#define NET_IPV4_TCP_NETIF_POLL_DISABLE          	 0x0000880a
#define NET_IPV4_TCP_WAIT_FOR_TCP_CONNECT        	 0x0000880b
#define NET_IPV4_TCP_WAIT_FOR_TCP_MEMORY         	 0x0000880c
#define NET_IPV4_TCP_TCP_DATA_WAIT               	 0x0000880d
#define NET_IPV4_TCP_TCP_CLOSE                   	 0x0000880e
#define NET_IPV4_TCP_WAIT_FOR_CONNECT            	 0x0000880f
#define NET_IPV4_TCP_INPUT_NETIF_POLL_DISABLE    	 0x00008810
#define NET_IPV4_TCP_OUTPUT_NETIF_POLL_DISABLE   	 0x00008811
#define NET_IPV4_TCP_TIMER_NETIF_POLL_DISABLE    	 0x00008812
#define NET_IPV4_TCP_IPV4_NETIF_POLL_DISABLE     	 0x00008813
#define NET_IPV4_TCP_IPV4_TCP_LISTEN_WLOCK       	 0x00008814
#define NET_IPV4_TCP_MINISOCKS_NETIF_POLL_DISABLE 	 0x00008815
#define NET_IPV4_TCP_DIAG_NETIF_POLL_DISABLE     	 0x00008816
#define NET_IPV4_RAW_NETIF_POLL_DISABLE          	 0x00008817
#define NET_IPV4_UDP_NETIF_POLL_DISABLE          	 0x00008818
#define NET_IPV4_ARP_NETIF_POLL_DISABLE          	 0x00008819
#define NET_IPV4_ICMP_NETIF_POLL_DISABLE         	 0x0000881a
#define NET_IPV4_DEVINET_NETIF_POLL_DISABLE      	 0x0000881b
#define NET_IPV4_AF_INET_NETIF_POLL_DISABLE      	 0x0000881c
#define NET_IPV4_AF_INET_INET_WAIT_FOR_CONNECT   	 0x0000881d
#define NET_IPV4_IGMP_NETIF_POLL_DISABLE         	 0x0000881e
#define NET_IPV4_SYSCTL_NET_IPV4_NETIF_POLL_DISABLE 	 0x0000881f
#define NET_IPV4_FIB_FRONTEND_NETIF_POLL_DISABLE 	 0x00008820
#define NET_IPV4_FIB_SEMANTICS_NETIF_POLL_DISABLE 	 0x00008821
#define NET_IPV4_FIB_HASH_NETIF_POLL_DISABLE     	 0x00008822
#define NET_IPV4_FIB_RULES_NETIF_POLL_DISABLE    	 0x00008823
#define NET_IPV4_IP_NAT_DUMB_NETIF_POLL_DISABLE  	 0x00008824
#define NET_IPV4_IPMR_NETIF_POLL_DISABLE         	 0x00008825
#define NET_IPV4_IPIP_NETIF_POLL_DISABLE         	 0x00008826
#define NET_IPV4_IP_GRE_NETIF_POLL_DISABLE       	 0x00008827
#define NET_IPV4_SYNCOOKIES_NETIF_POLL_DISABLE   	 0x00008828
#define NET_IPV4_IPCONFIG_NETIF_POLL_DISABLE     	 0x00008829
#define NET_IPV4_IPVS_IP_VS_CONN_NETIF_POLL_DISABLE 	 0x0000882a
#define NET_IPV4_IPVS_IP_VS_CONN_IP_VS_CONN_FLUSH 	 0x0000882b
#define NET_IPV4_IPVS_IP_VS_CORE_NETIF_POLL_DISABLE 	 0x0000882c
#define NET_IPV4_IPVS_IP_VS_CTL_NETIF_POLL_DISABLE 	 0x0000882d
#define NET_IPV4_IPVS_IP_VS_SCHED_NETIF_POLL_DISABLE 	 0x0000882e
#define NET_IPV4_IPVS_IP_VS_APP_NETIF_POLL_DISABLE 	 0x0000882f
#define NET_IPV4_IPVS_IP_VS_SYNC_NETIF_POLL_DISABLE 	 0x00008830
#define NET_IPV4_IPVS_IP_VS_SYNC_SYNC_MASTER_LOOP 	 0x00008831
#define NET_IPV4_IPVS_IP_VS_SYNC_SYNC_BACKUP_LOOP 	 0x00008832
#define NET_IPV4_IPVS_IP_VS_SYNC_STOP_SYNC_THREAD 	 0x00008833
#define NET_IPV4_IPVS_IP_VS_EST_NETIF_POLL_DISABLE 	 0x00008834
#define NET_IPV4_IPVS_IP_VS_RR_NETIF_POLL_DISABLE 	 0x00008835
#define NET_IPV4_IPVS_IP_VS_WRR_NETIF_POLL_DISABLE 	 0x00008836
#define NET_IPV4_IPVS_IP_VS_LC_NETIF_POLL_DISABLE 	 0x00008837
#define NET_IPV4_IPVS_IP_VS_WLC_NETIF_POLL_DISABLE 	 0x00008838
#define NET_IPV4_IPVS_IP_VS_LBLC_NETIF_POLL_DISABLE 	 0x00008839
#define NET_IPV4_IPVS_IP_VS_LBLCR_NETIF_POLL_DISABLE 	 0x0000883a
#define NET_IPV4_IPVS_IP_VS_DH_NETIF_POLL_DISABLE 	 0x0000883b
#define NET_IPV4_IPVS_IP_VS_SH_NETIF_POLL_DISABLE 	 0x0000883c
#define NET_IPV4_IPVS_IP_VS_SED_NETIF_POLL_DISABLE 	 0x0000883d
#define NET_IPV4_IPVS_IP_VS_NQ_NETIF_POLL_DISABLE 	 0x0000883e
#define NET_IPV4_IPVS_IP_VS_FTP_NETIF_POLL_DISABLE 	 0x0000883f
#define NET_IPV4_NETFILTER_IP_CONNTRACK_STANDALONE_NETIF_POLL_DISABLE 	 0x00008840
#define NET_IPV4_NETFILTER_IP_CONNTRACK_CORE_NETIF_POLL_DISABLE 	 0x00008841
#define NET_IPV4_NETFILTER_IP_CONNTRACK_CORE_IP_CONNTRACK_CLEANUP 	 0x00008842
#define NET_IPV4_NETFILTER_IP_CONNTRACK_PROTO_TCP_NETIF_POLL_DISABLE 	 0x00008843
#define NET_IPV4_NETFILTER_IP_CONNTRACK_AMANDA_NETIF_POLL_DISABLE 	 0x00008844
#define NET_IPV4_NETFILTER_IP_CONNTRACK_FTP_NETIF_POLL_DISABLE 	 0x00008845
#define NET_IPV4_NETFILTER_IP_CONNTRACK_IRC_NETIF_POLL_DISABLE 	 0x00008846
#define NET_IPV4_NETFILTER_IP_NAT_AMANDA_NETIF_POLL_DISABLE 	 0x00008847
#define NET_IPV4_NETFILTER_IP_NAT_FTP_NETIF_POLL_DISABLE 	 0x00008848
#define NET_IPV4_NETFILTER_IP_NAT_IRC_NETIF_POLL_DISABLE 	 0x00008849
#define NET_IPV4_NETFILTER_IP_TABLES_NETIF_POLL_DISABLE 	 0x0000884a
#define NET_IPV4_NETFILTER_IPTABLE_MANGLE_NETIF_POLL_DISABLE 	 0x0000884b
#define NET_IPV4_NETFILTER_IP_NAT_STANDALONE_NETIF_POLL_DISABLE 	 0x0000884c
#define NET_IPV4_NETFILTER_IP_NAT_RULE_NETIF_POLL_DISABLE 	 0x0000884d
#define NET_IPV4_NETFILTER_IP_NAT_CORE_NETIF_POLL_DISABLE 	 0x0000884e
#define NET_IPV4_NETFILTER_IP_NAT_HELPER_NETIF_POLL_DISABLE 	 0x0000884f
#define NET_IPV4_NETFILTER_IPT_OWNER_NETIF_POLL_DISABLE 	 0x00008850
#define NET_IPV4_NETFILTER_IPT_UNCLEAN_NETIF_POLL_DISABLE 	 0x00008851
#define NET_IPV4_NETFILTER_IPT_TCPMSS_NETIF_POLL_DISABLE 	 0x00008852
#define NET_IPV4_NETFILTER_IPT_REJECT_NETIF_POLL_DISABLE 	 0x00008853
#define NET_IPV4_NETFILTER_IPT_MIRROR_NETIF_POLL_DISABLE 	 0x00008854
#define NET_IPV4_NETFILTER_IPT_TOS_NETIF_POLL_DISABLE 	 0x00008855
#define NET_IPV4_NETFILTER_IPT_ECN_NETIF_POLL_DISABLE 	 0x00008856
#define NET_IPV4_NETFILTER_IPT_DSCP_NETIF_POLL_DISABLE 	 0x00008857
#define NET_IPV4_NETFILTER_IPT_MARK_NETIF_POLL_DISABLE 	 0x00008858
#define NET_IPV4_NETFILTER_IPT_MASQUERADE_NETIF_POLL_DISABLE 	 0x00008859
#define NET_IPV4_NETFILTER_IPT_REDIRECT_NETIF_POLL_DISABLE 	 0x0000885a
#define NET_IPV4_NETFILTER_IP_NAT_SNMP_BASIC_NETIF_POLL_DISABLE 	 0x0000885b
#define NET_IPV4_NETFILTER_IPT_LOG_NETIF_POLL_DISABLE 	 0x0000885c
#define NET_IPV4_NETFILTER_IPT_ULOG_NETIF_POLL_DISABLE 	 0x0000885d
#define NET_IPV4_NETFILTER_ARP_TABLES_NETIF_POLL_DISABLE 	 0x0000885e
#define NET_IPV4_NETFILTER_ARPT_MANGLE_NETIF_POLL_DISABLE 	 0x0000885f
#define NET_IPV4_NETFILTER_ARPTABLE_FILTER_NETIF_POLL_DISABLE 	 0x00008860
#define NET_IPV4_NETFILTER_IP_QUEUE_NETIF_POLL_DISABLE 	 0x00008861
#define NET_IPV6_AF_INET6_NETIF_POLL_DISABLE     	 0x00008901
#define NET_IPV6_ANYCAST_NETIF_POLL_DISABLE      	 0x00008902
#define NET_IPV6_IP6_OUTPUT_NETIF_POLL_DISABLE   	 0x00008903
#define NET_IPV6_IP6_INPUT_NETIF_POLL_DISABLE    	 0x00008904
#define NET_IPV6_ADDRCONF_NETIF_POLL_DISABLE     	 0x00008905
#define NET_IPV6_SIT_NETIF_POLL_DISABLE          	 0x00008906
#define NET_IPV6_ROUTE_NETIF_POLL_DISABLE        	 0x00008907
#define NET_IPV6_IP6_FIB_NETIF_POLL_DISABLE      	 0x00008908
#define NET_IPV6_IPV6_SOCKGLUE_NETIF_POLL_DISABLE 	 0x00008909
#define NET_IPV6_NDISC_NETIF_POLL_DISABLE        	 0x0000890a
#define NET_IPV6_UDP_NETIF_POLL_DISABLE          	 0x0000890b
#define NET_IPV6_RAW_NETIF_POLL_DISABLE          	 0x0000890c
#define NET_IPV6_PROTOCOL_NETIF_POLL_DISABLE     	 0x0000890d
#define NET_IPV6_ICMP_NETIF_POLL_DISABLE         	 0x0000890e
#define NET_IPV6_MCAST_NETIF_POLL_DISABLE        	 0x0000890f
#define NET_IPV6_REASSEMBLY_NETIF_POLL_DISABLE   	 0x00008910
#define NET_IPV6_TCP_IPV6_NETIF_POLL_DISABLE     	 0x00008911
#define NET_IPV6_EXTHDRS_NETIF_POLL_DISABLE      	 0x00008912
#define NET_IPV6_SYSCTL_NET_IPV6_NETIF_POLL_DISABLE 	 0x00008913
#define NET_IPV6_DATAGRAM_NETIF_POLL_DISABLE     	 0x00008914
#define NET_IPV6_PROC_NETIF_POLL_DISABLE         	 0x00008915
#define NET_IPV6_IP6_FLOWLABEL_NETIF_POLL_DISABLE 	 0x00008916
#define NET_IPV6_IPV6_SYMS_NETIF_POLL_DISABLE    	 0x00008917
#define NET_IPV6_NETFILTER_IP6_TABLES_NETIF_POLL_DISABLE 	 0x00008918
#define NET_IPV6_NETFILTER_IP6T_RT_NETIF_POLL_DISABLE 	 0x00008919
#define NET_IPV6_NETFILTER_IP6T_HBH_NETIF_POLL_DISABLE 	 0x0000891a
#define NET_IPV6_NETFILTER_IP6T_DST_NETIF_POLL_DISABLE 	 0x0000891b
#define NET_IPV6_NETFILTER_IP6T_IPV6HEADER_NETIF_POLL_DISABLE 	 0x0000891c
#define NET_IPV6_NETFILTER_IP6T_FRAG_NETIF_POLL_DISABLE 	 0x0000891d
#define NET_IPV6_NETFILTER_IP6T_ESP_NETIF_POLL_DISABLE 	 0x0000891e
#define NET_IPV6_NETFILTER_IP6T_AH_NETIF_POLL_DISABLE 	 0x0000891f
#define NET_IPV6_NETFILTER_IP6T_OWNER_NETIF_POLL_DISABLE 	 0x00008920
#define NET_IPV6_NETFILTER_IP6T_MARK_NETIF_POLL_DISABLE 	 0x00008921
#define NET_IPV6_NETFILTER_IP6_QUEUE_NETIF_POLL_DISABLE 	 0x00008922
#define NET_IPV6_NETFILTER_IP6T_LOG_NETIF_POLL_DISABLE 	 0x00008923
#define NET_IPX_AF_IPX_NETIF_POLL_DISABLE        	 0x00008a01
#define NET_IRDA_IRCOMM_IRCOMM_CORE_NETIF_POLL_DISABLE 	 0x00008b01
#define NET_IRDA_IRCOMM_IRCOMM_EVENT_NETIF_POLL_DISABLE 	 0x00008b02
#define NET_IRDA_IRCOMM_IRCOMM_LMP_NETIF_POLL_DISABLE 	 0x00008b03
#define NET_IRDA_IRCOMM_IRCOMM_TTP_NETIF_POLL_DISABLE 	 0x00008b04
#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_BLOCK_TIL_READY 	 0x00008b05
#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_CLOSE 	 0x00008b06
#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_WAIT_UNTIL_SENT 	 0x00008b07
#define NET_IRDA_IRCOMM_IRCOMM_TTY_ATTACH_NETIF_POLL_DISABLE 	 0x00008b08
#define NET_IRDA_IRLAN_IRLAN_COMMON_NETIF_POLL_DISABLE 	 0x00008b09
#define NET_IRDA_IRLAN_IRLAN_ETH_NETIF_POLL_DISABLE 	 0x00008b0a
#define NET_IRDA_IRLAN_IRLAN_EVENT_NETIF_POLL_DISABLE 	 0x00008b0b
#define NET_IRDA_IRLAN_IRLAN_CLIENT_NETIF_POLL_DISABLE 	 0x00008b0c
#define NET_IRDA_IRLAN_IRLAN_PROVIDER_NETIF_POLL_DISABLE 	 0x00008b0d
#define NET_IRDA_IRLAN_IRLAN_FILTER_NETIF_POLL_DISABLE 	 0x00008b0e
#define NET_IRDA_IRLAN_IRLAN_PROVIDER_EVENT_NETIF_POLL_DISABLE 	 0x00008b0f
#define NET_IRDA_IRLAN_IRLAN_CLIENT_EVENT_NETIF_POLL_DISABLE 	 0x00008b10
#define NET_IRDA_IRNET_IRNET_PPP_NETIF_POLL_DISABLE 	 0x00008b11
#define NET_IRDA_IRNET_IRNET_PPP_IRNET_CTRL_READ 	 0x00008b12
#define NET_IRDA_IRNET_IRNET_IRDA_NETIF_POLL_DISABLE 	 0x00008b13
#define NET_IRDA_IRIAP_NETIF_POLL_DISABLE        	 0x00008b14
#define NET_IRDA_IRIAP_EVENT_NETIF_POLL_DISABLE  	 0x00008b15
#define NET_IRDA_IRLMP_NETIF_POLL_DISABLE        	 0x00008b16
#define NET_IRDA_IRLMP_EVENT_NETIF_POLL_DISABLE  	 0x00008b17
#define NET_IRDA_IRLMP_FRAME_NETIF_POLL_DISABLE  	 0x00008b18
#define NET_IRDA_IRLAP_NETIF_POLL_DISABLE        	 0x00008b19
#define NET_IRDA_IRLAP_EVENT_NETIF_POLL_DISABLE  	 0x00008b1a
#define NET_IRDA_IRLAP_FRAME_NETIF_POLL_DISABLE  	 0x00008b1b
#define NET_IRDA_TIMER_NETIF_POLL_DISABLE        	 0x00008b1c
#define NET_IRDA_QOS_NETIF_POLL_DISABLE          	 0x00008b1d
#define NET_IRDA_IRTTP_NETIF_POLL_DISABLE        	 0x00008b1e
#define NET_IRDA_IRDA_DEVICE_NETIF_POLL_DISABLE  	 0x00008b1f
#define NET_IRDA_WRAPPER_NETIF_POLL_DISABLE      	 0x00008b20
#define NET_IRDA_AF_IRDA_NETIF_POLL_DISABLE      	 0x00008b21
#define NET_IRDA_DISCOVERY_NETIF_POLL_DISABLE    	 0x00008b22
#define NET_IRDA_IRSYMS_NETIF_POLL_DISABLE       	 0x00008b23
#define NET_IRDA_IRPROC_NETIF_POLL_DISABLE       	 0x00008b24
#define NET_KHTTPD_MAIN_NETIF_POLL_DISABLE       	 0x00008c01
#define NET_KHTTPD_ACCEPT_NETIF_POLL_DISABLE     	 0x00008c02
#define NET_KHTTPD_DATASENDING_NETIF_POLL_DISABLE 	 0x00008c03
#define NET_KHTTPD_LOGGING_NETIF_POLL_DISABLE    	 0x00008c04
#define NET_KHTTPD_MISC_NETIF_POLL_DISABLE       	 0x00008c05
#define NET_KHTTPD_RFC_NETIF_POLL_DISABLE        	 0x00008c06
#define NET_KHTTPD_RFC_TIME_NETIF_POLL_DISABLE   	 0x00008c07
#define NET_KHTTPD_SECURITY_NETIF_POLL_DISABLE   	 0x00008c08
#define NET_KHTTPD_SOCKETS_NETIF_POLL_DISABLE    	 0x00008c09
#define NET_KHTTPD_SYSCTL_NETIF_POLL_DISABLE     	 0x00008c0a
#define NET_KHTTPD_USERSPACE_NETIF_POLL_DISABLE  	 0x00008c0b
#define NET_KHTTPD_WAITHEADERS_NETIF_POLL_DISABLE 	 0x00008c0c
#define NET_LAPB_LAPB_IN_NETIF_POLL_DISABLE      	 0x00008d01
#define NET_LAPB_LAPB_OUT_NETIF_POLL_DISABLE     	 0x00008d02
#define NET_LAPB_LAPB_SUBR_NETIF_POLL_DISABLE    	 0x00008d03
#define NET_LAPB_LAPB_TIMER_NETIF_POLL_DISABLE   	 0x00008d04
#define NET_LAPB_LAPB_IFACE_NETIF_POLL_DISABLE   	 0x00008d05
#define NET_NETLINK_AF_NETLINK_NETIF_POLL_DISABLE 	 0x00008e01
#define NET_NETLINK_AF_NETLINK_NETLINK_TABLE_GRAB 	 0x00008e02
#define NET_NETLINK_AF_NETLINK_NETLINK_UNICAST   	 0x00008e03
#define NET_NETROM_AF_NETROM_NETIF_POLL_DISABLE  	 0x00008f01
#define NET_NETROM_NR_DEV_NETIF_POLL_DISABLE     	 0x00008f02
#define NET_NETROM_NR_IN_NETIF_POLL_DISABLE      	 0x00008f03
#define NET_NETROM_NR_LOOPBACK_NETIF_POLL_DISABLE 	 0x00008f04
#define NET_NETROM_NR_OUT_NETIF_POLL_DISABLE     	 0x00008f05
#define NET_NETROM_NR_ROUTE_NETIF_POLL_DISABLE   	 0x00008f06
#define NET_NETROM_NR_SUBR_NETIF_POLL_DISABLE    	 0x00008f07
#define NET_NETROM_NR_TIMER_NETIF_POLL_DISABLE   	 0x00008f08
#define NET_NETROM_SYSCTL_NET_NETROM_NETIF_POLL_DISABLE 	 0x00008f09
#define NET_PACKET_AF_PACKET_NETIF_POLL_DISABLE  	 0x00009001
#define NET_ROSE_AF_ROSE_NETIF_POLL_DISABLE      	 0x00009101
#define NET_ROSE_ROSE_DEV_NETIF_POLL_DISABLE     	 0x00009102
#define NET_ROSE_ROSE_IN_NETIF_POLL_DISABLE      	 0x00009103
#define NET_ROSE_ROSE_LINK_NETIF_POLL_DISABLE    	 0x00009104
#define NET_ROSE_ROSE_LOOPBACK_NETIF_POLL_DISABLE 	 0x00009105
#define NET_ROSE_ROSE_OUT_NETIF_POLL_DISABLE     	 0x00009106
#define NET_ROSE_ROSE_ROUTE_NETIF_POLL_DISABLE   	 0x00009107
#define NET_ROSE_ROSE_SUBR_NETIF_POLL_DISABLE    	 0x00009108
#define NET_ROSE_ROSE_TIMER_NETIF_POLL_DISABLE   	 0x00009109
#define NET_ROSE_SYSCTL_NET_ROSE_NETIF_POLL_DISABLE 	 0x0000910a
#define NET_SCHED_SCH_GENERIC_NETIF_POLL_DISABLE 	 0x00009201
#define NET_SCHED_SCH_API_NETIF_POLL_DISABLE     	 0x00009202
#define NET_SCHED_SCH_FIFO_NETIF_POLL_DISABLE    	 0x00009203
#define NET_SCHED_ESTIMATOR_NETIF_POLL_DISABLE   	 0x00009204
#define NET_SCHED_CLS_API_NETIF_POLL_DISABLE     	 0x00009205
#define NET_SCHED_POLICE_NETIF_POLL_DISABLE      	 0x00009206
#define NET_SCHED_SCH_INGRESS_NETIF_POLL_DISABLE 	 0x00009207
#define NET_SCHED_SCH_CBQ_NETIF_POLL_DISABLE     	 0x00009208
#define NET_SCHED_SCH_CSZ_NETIF_POLL_DISABLE     	 0x00009209
#define NET_SCHED_SCH_HTB_NETIF_POLL_DISABLE     	 0x0000920a
#define NET_SCHED_SCH_SFQ_NETIF_POLL_DISABLE     	 0x0000920b
#define NET_SCHED_SCH_RED_NETIF_POLL_DISABLE     	 0x0000920c
#define NET_SCHED_SCH_TBF_NETIF_POLL_DISABLE     	 0x0000920d
#define NET_SCHED_SCH_PRIO_NETIF_POLL_DISABLE    	 0x0000920e
#define NET_SCHED_SCH_TEQL_NETIF_POLL_DISABLE    	 0x0000920f
#define NET_SCHED_SCH_GRED_NETIF_POLL_DISABLE    	 0x00009210
#define NET_SCHED_SCH_DSMARK_NETIF_POLL_DISABLE  	 0x00009211
#define NET_SCHED_CLS_TCINDEX_NETIF_POLL_DISABLE 	 0x00009212
#define NET_SCHED_SCH_ATM_NETIF_POLL_DISABLE     	 0x00009213
#define NET_SCHED_CLS_U32_NETIF_POLL_DISABLE     	 0x00009214
#define NET_SCHED_CLS_RSVP_NETIF_POLL_DISABLE    	 0x00009215
#define NET_SCHED_CLS_RSVP6_NETIF_POLL_DISABLE   	 0x00009216
#define NET_SCHED_CLS_ROUTE_NETIF_POLL_DISABLE   	 0x00009217
#define NET_SCHED_CLS_FW_NETIF_POLL_DISABLE      	 0x00009218
#define NET_SCTP_ENDPOINTOLA_NETIF_POLL_DISABLE  	 0x00009301
#define NET_SCTP_OUTPUT_NETIF_POLL_DISABLE       	 0x00009302
#define NET_SCTP_SM_MAKE_CHUNK_NETIF_POLL_DISABLE 	 0x00009303
#define NET_SCTP_ASSOCIOLA_NETIF_POLL_DISABLE    	 0x00009304
#define NET_SCTP_HASHDRIVER_NETIF_POLL_DISABLE   	 0x00009305
#define NET_SCTP_OUTQUEUE_NETIF_POLL_DISABLE     	 0x00009306
#define NET_SCTP_SM_SIDEEFFECT_NETIF_POLL_DISABLE 	 0x00009307
#define NET_SCTP_TRANSPORT_NETIF_POLL_DISABLE    	 0x00009308
#define NET_SCTP_BIND_ADDR_NETIF_POLL_DISABLE    	 0x00009309
#define NET_SCTP_INPUT_NETIF_POLL_DISABLE        	 0x0000930a
#define NET_SCTP_PRIMITIVE_NETIF_POLL_DISABLE    	 0x0000930b
#define NET_SCTP_SM_STATEFUNS_NETIF_POLL_DISABLE 	 0x0000930c
#define NET_SCTP_TSNMAP_NETIF_POLL_DISABLE       	 0x0000930d
#define NET_SCTP_COMMAND_NETIF_POLL_DISABLE      	 0x0000930e
#define NET_SCTP_INQUEUE_NETIF_POLL_DISABLE      	 0x0000930f
#define NET_SCTP_PROC_NETIF_POLL_DISABLE         	 0x00009310
#define NET_SCTP_SM_STATETABLE_NETIF_POLL_DISABLE 	 0x00009311
#define NET_SCTP_ULPEVENT_NETIF_POLL_DISABLE     	 0x00009312
#define NET_SCTP_PROTOCOL_NETIF_POLL_DISABLE     	 0x00009313
#define NET_SCTP_SOCKET_NETIF_POLL_DISABLE       	 0x00009314
#define NET_SCTP_SOCKET_SCTP_WAIT_FOR_PACKET     	 0x00009315
#define NET_SCTP_SOCKET_SCTP_WAIT_FOR_SNDBUF     	 0x00009316
#define NET_SCTP_SOCKET_SCTP_WAIT_FOR_CONNECT    	 0x00009317
#define NET_SCTP_SOCKET_SCTP_WAIT_FOR_ACCEPT     	 0x00009318
#define NET_SCTP_ULPQUEUE_NETIF_POLL_DISABLE     	 0x00009319
#define NET_SCTP_DEBUG_NETIF_POLL_DISABLE        	 0x0000931a
#define NET_SCTP_SSNMAP_NETIF_POLL_DISABLE       	 0x0000931b
#define NET_SCTP_ADLER32_NETIF_POLL_DISABLE      	 0x0000931c
#define NET_SCTP_OBJCNT_NETIF_POLL_DISABLE       	 0x0000931d
#define NET_SCTP_IPV6_NETIF_POLL_DISABLE         	 0x0000931e
#define NET_SUNRPC_XPRT_NETIF_POLL_DISABLE       	 0x00009401
#define NET_SUNRPC_SCHED___RPC_EXECUTE           	 0x00009402
#define NET_SUNRPC_SCHED___RPC_SCHEDULE          	 0x00009403
#define NET_SUNRPC_SCHED_RPCIOD                  	 0x00009404
#define NET_SUNRPC_SVCSOCK_NETIF_POLL_DISABLE    	 0x00009405
#define NET_SUNRPC_SVCSOCK_SVC_RECV              	 0x00009406
#define NET_UNIX_AF_UNIX_NETIF_POLL_DISABLE      	 0x00009501
#define NET_UNIX_AF_UNIX_UNIX_WAIT_FOR_PEER      	 0x00009502
#define NET_UNIX_AF_UNIX_UNIX_STREAM_DATA_WAIT   	 0x00009503
#define NET_UNIX_GARBAGE_NETIF_POLL_DISABLE      	 0x00009504
#define NET_WANROUTER_WANPROC_NETIF_POLL_DISABLE 	 0x00009601
#define NET_WANROUTER_WANMAIN_NETIF_POLL_DISABLE 	 0x00009602
#define NET_X25_AF_X25_NETIF_POLL_DISABLE        	 0x00009701
#define NET_X25_X25_DEV_NETIF_POLL_DISABLE       	 0x00009702
#define NET_X25_X25_FACILITIES_NETIF_POLL_DISABLE 	 0x00009703
#define NET_X25_X25_IN_NETIF_POLL_DISABLE        	 0x00009704
#define NET_X25_X25_LINK_NETIF_POLL_DISABLE      	 0x00009705
#define NET_X25_X25_OUT_NETIF_POLL_DISABLE       	 0x00009706
#define NET_X25_X25_ROUTE_NETIF_POLL_DISABLE     	 0x00009707
#define NET_X25_X25_SUBR_NETIF_POLL_DISABLE      	 0x00009708
#define NET_X25_X25_TIMER_NETIF_POLL_DISABLE     	 0x00009709
#define NET_X25_SYSCTL_NET_X25_NETIF_POLL_DISABLE 	 0x0000970a
#define NET_SOCKET_NETIF_POLL_DISABLE            	 0x00009801
#define NET_NETSYMS_NETIF_POLL_DISABLE           	 0x00009901
#define IPC_MSG_SYS_MSGSND                       	 0x00009a01
#define IPC_MSG_SYS_MSGRCV                       	 0x00009a02
#define IPC_SEM_SYS_SEMTIMEDOP                   	 0x00009b01
#define LIB_RWSEM_RWSEM_DOWN_FAILED_COMMON       	 0x00009c01
#define ARCH_I386_KERNEL_PROCESS_CPU_IDLE        	 0x00009d01
#define ARCH_I386_KERNEL_SEMAPHORE___DOWN        	 0x00009d02
#define ARCH_I386_KERNEL_SEMAPHORE___DOWN_INTERRUPTIBLE 	 0x00009d03
#define ARCH_I386_KERNEL_SIGNAL_SYS_SIGSUSPEND   	 0x00009d04
#define ARCH_I386_KERNEL_SIGNAL_SYS_RT_SIGSUSPEND 	 0x00009d05
#define ARCH_I386_KERNEL_SIGNAL_DO_SIGNAL        	 0x00009d06
#define ARCH_I386_KERNEL_PTRACE_SYSCALL_TRACE    	 0x00009d07
#define ARCH_I386_KERNEL_SYS_I386_SYS_PAUSE      	 0x00009d08
#define ARCH_I386_KERNEL_APM_APM_MAINLOOP        	 0x00009d09
#define ARCH_I386_KERNEL_APM_DO_READ             	 0x00009d0a
#define ARCH_I386_KERNEL_APM_DO_IOCTL            	 0x00009d0b
#define ARCH_I386_KERNEL_APM_APM_EXIT            	 0x00009d0c
#define ARCH_I386_LIB_OLD_CHECKSUM_NETIF_POLL_DISABLE 	 0x00009e01

#define EVENT_BLOCK					 0x01000000

#define EVENT_SYSTEM					 0x04000000
#define EVENT_SYSTEM_CLOCKTICK				 0x04010000

#define EVENT_PROCESS                 		 	 0x05000000
#define EVENT_PROCESS_NEW                                0x05010000
#define EVENT_PROCESS_END                                0x05020000
#define EVENT_PROCESS_END_USER                           0x05020100
#define EVENT_PROCESS_END_SYSTEM                         0x05020200

#define EVENT_UNBLOCK					 0x02000000
#define EVENT_UNBLOCK_NONPREEMPTIVE			 0x02030000
#define EVENT_UNBLOCK_PREEMPTIVE			 0x02040000
#define EVENT_UNBLOCK_TIMER				 0x02050000

#define EVENT_YIELD					 0x03000000
#define EVENT_YIELD_SYSTEM          			 0x03010000
#define EVENT_YIELD_SYSTEM_IMMEDIATE			 0x03010100
#define EVENT_YIELD_SYSTEM_PAUSE    			 0x03010200
#define EVENT_YIELD_USER				 0x03020000
#define EVENT_YIELD_USER_EDF				 0x03020100

#endif
