// the functions in list.h are used by the policy in the implementation
// of queues

#include <linux/list.h>

/************************************************************************/

// #include <linux/timer.h>
// the following type is used in the policy opaquely, but explicitly in
// task_struct

struct timer_list {
	struct list_head list;
	unsigned long expires;
	unsigned long data;
	void (*function)(unsigned long);
};

// #include <asm-i386/posix-types.h>
// the following types are used only in types.h

typedef long		__kernel_clock_t;
typedef int		__kernel_pid_t;
typedef unsigned short	__kernel_uid_t;
typedef unsigned int	__kernel_size_t;
typedef int		__kernel_ssize_t;
typedef long long	__kernel_loff_t;

// #include <linux/types.h>
// the following types are used in various places, but not the policy directly

typedef __kernel_clock_t	clock_t;
typedef __kernel_pid_t		pid_t;
typedef __kernel_uid32_t	uid_t;
typedef __kernel_size_t		size_t;
typedef __kernel_ssize_t	ssize_t;
typedef __kernel_loff_t		loff_t;

// #include <linux/times.h>
// the following type is used only in task_struct

struct tms {
	clock_t tms_utime;
	clock_t tms_stime;
	clock_t tms_cutime;
	clock_t tms_cstime;
};

// #include <linux/resource.h>
// the following type is used only in task_struct

struct rlimit {
	unsigned long	rlim_cur;
	unsigned long	rlim_max;
};

// #include <asm/atomic.h>
// the following type is used only in signal_struct, which is used
// only in task_struct

typedef struct { volatile int counter; } atomic_t;

// #include <asm-i386/system.h>
// used by spinlocks, which are used by the policy

#define local_irq_save(x)	__save_and_cli(x)
#define local_irq_restore(x)	__restore_flags(x)

// #include <linux/spinlock.h>
// the following type is used only in signal_struct, which is used
// only in task_struct, and in the policy

typedef struct { } spinlock_t;
#define spin_lock_irqsave(lock, flags)		do { local_irq_save(flags);       spin_lock(lock); } while (0)
#define spin_unlock_irqrestore(lock, flags)	do { spin_unlock(lock);  local_irq_restore(flags); } while (0)
#define spin_lock(lock)		(void)(lock) /* Not "unused variable". */
#define spin_unlock(lock)	do { } while(0)

// #include <asm-i386/signal.h>
// the following types are used only in signal_struct, which is used
// only in task_struct, and in sigpending, which is also used only in
// task_struct

typedef void (*__sighandler_t)(int);

typedef struct {
	unsigned long sig[_NSIG_WORDS];
} sigset_t;

struct sigaction {
	__sighandler_t sa_handler;
	unsigned long sa_flags;
	void (*sa_restorer)(void);
	sigset_t sa_mask;		/* mask last for extensibility */
};

struct k_sigaction {
	struct sigaction sa;
};

// #include <asm/siginfo.h>
// the following types are used only in sigqueue, which is used
// indirectly only in task_struct

typedef struct siginfo {
	int si_signo;
	int si_errno;
	int si_code;

	union {
		int _pad[SI_PAD_SIZE];

		/* kill() */
		struct {
			pid_t _pid;		/* sender's pid */
			uid_t _uid;		/* sender's uid */
		} _kill;

		/* POSIX.1b timers */
		struct {
			unsigned int _timer1;
			unsigned int _timer2;
		} _timer;

		/* POSIX.1b signals */
		struct {
			pid_t _pid;		/* sender's pid */
			uid_t _uid;		/* sender's uid */
			sigval_t _sigval;
		} _rt;

		/* SIGCHLD */
		struct {
			pid_t _pid;		/* which child */
			uid_t _uid;		/* sender's uid */
			int _status;		/* exit code */
			clock_t _utime;
			clock_t _stime;
		} _sigchld;

		/* SIGILL, SIGFPE, SIGSEGV, SIGBUS */
		struct {
			void *_addr; /* faulting insn/memory ref. */
		} _sigfault;

		/* SIGPOLL */
		struct {
			int _band;	/* POLL_IN, POLL_OUT, POLL_MSG */
			int _fd;
		} _sigpoll;
	} _sifields;
} siginfo_t;

// #include <linux/signal.h>
// the following types are used only in signal_struct, which is used
// only in task_struct

struct sigqueue {
	struct sigqueue *next;
	siginfo_t info;
};

struct sigpending {
	struct sigqueue *head, **tail;
	sigset_t signal;
};

// #include <linux/sched.h>
// We export the entire task structure so that a policy can refer to the
// process attributes

struct exec_domain
struct mm_struct
struct task_struct
struct linux_binfmt
struct completion
struct user_struct
struct tty_struct
struct sem_undo
struct sem_queue
struct thread_struct
struct fs_struct
struct files_struct
struct namespace

struct signal_struct {
	atomic_t		count;
	struct k_sigaction	action[_NSIG];
	spinlock_t		siglock;
};

struct task_struct {
	volatile long state;	/* -1 unrunnable, 0 runnable, >0 stopped */
	unsigned long flags;	/* per process flags, defined below */
	int sigpending;
	mm_segment_t addr_limit;
	struct exec_domain *exec_domain;
	volatile long need_resched;
	unsigned long ptrace;
	int lock_depth;		/* Lock depth */
	long counter;
	long nice;
	unsigned long policy;
	struct mm_struct *mm;
	int processor;
	unsigned long cpus_runnable, cpus_allowed;
	struct list_head run_list;
	unsigned long sleep_time;
	struct task_struct *next_task, *prev_task;
	struct mm_struct *active_mm;
	struct list_head local_pages;
	unsigned int allocation_order, nr_local_pages;
	struct linux_binfmt *binfmt;
	int exit_code, exit_signal;
	int pdeath_signal;  /*  The signal sent when the parent dies  */
	unsigned long personality;
	int did_exec:1;
	unsigned task_dumpable:1;
	pid_t pid;
	pid_t pgrp;
	pid_t tty_old_pgrp;
	pid_t session;
	pid_t tgid;
	int leader;
	struct task_struct *p_opptr, *p_pptr, *p_cptr, *p_ysptr, *p_osptr;
	struct list_head thread_group;
	struct task_struct *pidhash_next;
	struct task_struct **pidhash_pprev;
	wait_queue_head_t wait_chldexit;	/* for wait4() */
	struct completion *vfork_done;		/* for vfork() */
	unsigned long rt_priority;
	unsigned long it_real_value, it_prof_value, it_virt_value;
	unsigned long it_real_incr, it_prof_incr, it_virt_incr;
	struct timer_list real_timer;
	struct tms times;
	unsigned long start_time;
	long per_cpu_utime[NR_CPUS], per_cpu_stime[NR_CPUS];
	unsigned long min_flt, maj_flt, nswap, cmin_flt, cmaj_flt, cnswap;
	int swappable:1;
	uid_t uid,euid,suid,fsuid;
	gid_t gid,egid,sgid,fsgid;
	int ngroups;
	gid_t	groups[NGROUPS];
	kernel_cap_t   cap_effective, cap_inheritable, cap_permitted;
	int keep_capabilities:1;
	struct user_struct *user;
	struct rlimit rlim[RLIM_NLIMITS];
	unsigned short used_math;
	char comm[16];
	int link_count, total_link_count;
	struct tty_struct *tty; /* NULL if no tty */
	unsigned int locks; /* How many file locks are being held */
	struct sem_undo *semundo;
	struct sem_queue *semsleeping;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct namespace *namespace;
	spinlock_t sigmask_lock;	/* Protects signal and blocked */
	struct signal_struct *sig;

	sigset_t blocked;
	struct sigpending pending;

	unsigned long sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *priv);
	void *notifier_data;
	sigset_t *notifier_mask;
   	u32 parent_exec_id;
   	u32 self_exec_id;
	spinlock_t alloc_lock;
#ifdef CONFIG_BOSSA
	void *journal_info; struct bossa_struct bossa; int bossa_data[CONFIG_BOSSA_DATA_SIZE];
#else
	void *journal_info;
#endif
}

/************************************************************************/

// #include <linux/string.h>
// used by the policy

static inline char * strcpy(char * dest,const char *src)
{
int d0, d1, d2;
__asm__ __volatile__(
	"1:\tlodsb\n\t"
	"stosb\n\t"
	"testb %%al,%%al\n\t"
	"jne 1b"
	: "=&S" (d0), "=&D" (d1), "=&a" (d2)
	:"0" (src),"1" (dest) : "memory");
return dest;
}

/************************************************************************/

//#include <linux/slab.h>
// used by virtual scedulers

extern void *kmalloc(size_t, int);
extern void kfree(const void *);

/************************************************************************/

// the following is used by the policy
#include <linux/errno.h>

/************************************************************************/

// #include <linux/prefetch.h>
// the following is used by the policy
// this has the effect of never doing prefetching
#ifndef ARCH_HAS_PREFETCH
#define ARCH_HAS_PREFETCH
static inline void prefetch(const void *x) {;}
#endif

/************************************************************************/

//#include <linux/fs.h>
// inode, file, and file_operations are used by a policy.
// the rest are just for the fields of file_operations

struct inode;
struct file;

struct vm_area_struct;
struct dentry;
struct file_lock;
struct iovec;
struct page;

struct file_operations {
  struct module *owner;
  loff_t (*llseek) (struct file *, loff_t, int);
  ssize_t (*read) (struct file *, char *, size_t, loff_t *);
  ssize_t (*write) (struct file *, const char *, size_t, loff_t *);
  int (*readdir) (struct file *, void *, filldir_t);
  unsigned int (*poll) (struct file *, struct poll_table_struct *);
  int (*ioctl) (struct inode *, struct file *, unsigned int, unsigned long);
  int (*mmap) (struct file *, struct vm_area_struct *);
  int (*open) (struct inode *, struct file *);
  int (*flush) (struct file *);
  int (*release) (struct inode *, struct file *);
  int (*fsync) (struct file *, struct dentry *, int datasync);
  int (*fasync) (int, struct file *, int);
  int (*lock) (struct file *, int, struct file_lock *);
  ssize_t (*readv) (struct file *, const struct iovec *, unsigned long, loff_t *);
  ssize_t (*writev) (struct file *, const struct iovec *, unsigned long, loff_t *);
  ssize_t (*sendpage) (struct file *, struct page *, int, size_t, loff_t *, int);
  unsigned long (*get_unmapped_area)(struct file *, unsigned long, unsigned long, unsigned long, unsigned long);
};

/************************************************************************/

//#include <linux/devfs_fs_kernel.h>
// used by the policy

struct devfs_entry;
typedef struct devfs_entry * devfs_handle_t;
extern devfs_handle_t devfs_register (devfs_handle_t dir, const char *name,
				      unsigned int flags,
				      unsigned int major, unsigned int minor,
				      umode_t mode, void *ops, void *info);
extern devfs_handle_t devfs_mk_dir (devfs_handle_t dir, const char *name,
				    void *info);
extern int devfs_register_chrdev (unsigned int major, const char *name,
				  struct file_operations *fops);

/************************************************************************/

// used by the policy to communicate with the user process
#include <asm/uaccess.h>

/************************************************************************/

//#include <asm/ioctl.h>
// used by the policy

/*
 * Direction bits.
 */
#define _IOC_NONE	0U
#define _IOC_WRITE	1U
#define _IOC_READ	2U

#define _IOC(dir,type,nr,size) \
	(((dir)  << _IOC_DIRSHIFT) | \
	 ((type) << _IOC_TYPESHIFT) | \
	 ((nr)   << _IOC_NRSHIFT) | \
	 ((size) << _IOC_SIZESHIFT))

/* used to create numbers */
#define _IO(type,nr)		_IOC(_IOC_NONE,(type),(nr),0)
#define _IOR(type,nr,size)	_IOC(_IOC_READ,(type),(nr),sizeof(size))
#define _IOW(type,nr,size)	_IOC(_IOC_WRITE,(type),(nr),sizeof(size))
#define _IOWR(type,nr,size)	_IOC(_IOC_READ|_IOC_WRITE,(type),(nr),sizeof(size))

/************************************************************************/

#include <linux/module.h> /* Ncessaire pour tous les modules */

/************************************************************************/

#include <linux/kernel.h> /* Ncessaire pour le alertes noyau */

/************************************************************************/

#include <linux/init.h>   /* Ncessaire pour l'utilisation module_init()/_exit()*/

/************************************************************************/

